@@ -1,7 +1,7 @@
 from pydantic import BaseModel, Field
-from typing import Any, Generic, Literal, Optional, Type, TypeVar, Union, overload
+from typing import Any, Generic, Literal, Type, TypeVar, overload
 from typing_extensions import Annotated
-from maleo.types.string import OptionalListOfStrings, OptionalString
+from maleo.types.string import OptListOfStrs, OptStr
 from .descriptor import (
     ErrorDescriptorT,
     ErrorDescriptorMixin,
@@ -19,7 +19,7 @@ from .descriptor import (
     ServiceUnavailableErrorDescriptor,
     Factory as ErrorDescriptorFactory,
 )
-from .enums import Code as ErrorCode
+from .enums import ErrorCode
 from .metadata import ErrorMetadata, ErrorMetadataMixin
 from .spec import (
     ErrorSpecT,
@@ -181,37 +181,37 @@ class ServiceUnavailableError(
     ] = ServiceUnavailableErrorDescriptor()
 
 
-AnyErrorType = Union[
-    Type[BadRequestError],
-    Type[UnauthorizedError],
-    Type[ForbiddenError],
-    Type[NotFoundError],
-    Type[MethodNotAllowedError],
-    Type[ConflictError],
-    Type[UnprocessableEntityError],
-    Type[TooManyRequestsError],
-    Type[InternalServerError],
-    Type[NotImplementedError],
-    Type[BadGatewayError],
-    Type[ServiceUnavailableError],
-]
-AnyError = Union[
-    BadRequestError,
-    UnauthorizedError,
-    ForbiddenError,
-    NotFoundError,
-    MethodNotAllowedError,
-    ConflictError,
-    UnprocessableEntityError,
-    TooManyRequestsError,
-    InternalServerError,
-    NotImplementedError,
-    BadGatewayError,
-    ServiceUnavailableError,
-]
+AnyErrorType = (
+    Type[BadRequestError]
+    | Type[UnauthorizedError]
+    | Type[ForbiddenError]
+    | Type[NotFoundError]
+    | Type[MethodNotAllowedError]
+    | Type[ConflictError]
+    | Type[UnprocessableEntityError]
+    | Type[TooManyRequestsError]
+    | Type[InternalServerError]
+    | Type[NotImplementedError]
+    | Type[BadGatewayError]
+    | Type[ServiceUnavailableError]
+)
+AnyError = (
+    BadRequestError
+    | UnauthorizedError
+    | ForbiddenError
+    | NotFoundError
+    | MethodNotAllowedError
+    | ConflictError
+    | UnprocessableEntityError
+    | TooManyRequestsError
+    | InternalServerError
+    | NotImplementedError
+    | BadGatewayError
+    | ServiceUnavailableError
+)
 AnyErrorT = TypeVar("AnyErrorT", bound=AnyError)
-OptionalAnyError = Optional[AnyError]
-OptionalAnyErrorT = TypeVar("OptionalAnyErrorT", bound=OptionalAnyError)
+OptAnyError = AnyError | None
+OptAnyErrorT = TypeVar("OptAnyErrorT", bound=OptAnyError)
 
 
 class Factory:
@@ -290,12 +290,12 @@ class Factory:
     @overload
     @staticmethod
     def cls_from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorType: ...
     @staticmethod
     def cls_from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorType:
         if code is ErrorCode.BAD_REQUEST or code == 400:
@@ -329,139 +329,139 @@ class Factory:
     def from_code(
         code: Literal[ErrorCode.BAD_REQUEST, 400],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> BadRequestError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.UNAUTHORIZED, 401],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> UnauthorizedError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.FORBIDDEN, 403],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> ForbiddenError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.NOT_FOUND, 404],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> NotFoundError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.METHOD_NOT_ALLOWED, 405],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> MethodNotAllowedError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.CONFLICT, 409],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> ConflictError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.UNPROCESSABLE_ENTITY, 422],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> UnprocessableEntityError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.TOO_MANY_REQUESTS, 429],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> TooManyRequestsError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.INTERNAL_SERVER_ERROR, 500],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> InternalServerError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.NOT_IMPLEMENTED, 501],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> NotImplementedError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.BAD_GATEWAY, 502],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> BadGatewayError: ...
     @overload
     @staticmethod
     def from_code(
         code: Literal[ErrorCode.SERVICE_UNAVAILABLE, 503],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> ServiceUnavailableError: ...
     @overload
     @staticmethod
     def from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> AnyError: ...
     @staticmethod
     def from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         details: Any = None,
-        traceback: OptionalListOfStrings = None,
+        traceback: OptListOfStrs = None,
     ) -> AnyError:
         return Factory.cls_from_code(code)(
             spec=ErrorSpecFactory.from_code(code),  # type: ignore
@@ -472,5 +472,5 @@ class Factory:
         )
 
 
-class ErrorMixin(BaseModel, Generic[OptionalAnyErrorT]):
-    error: OptionalAnyErrorT = Field(..., description="Error")
+class ErrorMixin(BaseModel, Generic[OptAnyErrorT]):
+    error: OptAnyErrorT = Field(..., description="Error")
