@@ -1,9 +1,9 @@
 from pydantic import BaseModel, Field
-from typing import Generic, Literal, Type, TypeVar, Union, overload
+from typing import Generic, Literal, Type, TypeVar, overload
 from typing_extensions import Annotated
 from ..mixins.general import StatusCode
 from .enums import ErrorType as ErrorTypeEnum
-from .enums import Code as ErrorCode
+from .enums import ErrorCode
 
 
 class ErrorType(BaseModel):
@@ -86,34 +86,34 @@ class ServiceUnavailableErrorSpec(ErrorSpec):
     status_code: int = 503
 
 
-AnyErrorSpecType = Union[
-    Type[BadRequestErrorSpec],
-    Type[UnauthorizedErrorSpec],
-    Type[ForbiddenErrorSpec],
-    Type[NotFoundErrorSpec],
-    Type[MethodNotAllowedErrorSpec],
-    Type[ConflictErrorSpec],
-    Type[UnprocessableEntityErrorSpec],
-    Type[TooManyRequestsErrorSpec],
-    Type[InternalServerErrorSpec],
-    Type[NotImplementedErrorSpec],
-    Type[BadGatewayErrorSpec],
-    Type[ServiceUnavailableErrorSpec],
-]
-AnyErrorSpec = Union[
-    BadRequestErrorSpec,
-    UnauthorizedErrorSpec,
-    ForbiddenErrorSpec,
-    NotFoundErrorSpec,
-    MethodNotAllowedErrorSpec,
-    ConflictErrorSpec,
-    UnprocessableEntityErrorSpec,
-    TooManyRequestsErrorSpec,
-    InternalServerErrorSpec,
-    NotImplementedErrorSpec,
-    BadGatewayErrorSpec,
-    ServiceUnavailableErrorSpec,
-]
+AnyErrorSpecType = (
+    Type[BadRequestErrorSpec]
+    | Type[UnauthorizedErrorSpec]
+    | Type[ForbiddenErrorSpec]
+    | Type[NotFoundErrorSpec]
+    | Type[MethodNotAllowedErrorSpec]
+    | Type[ConflictErrorSpec]
+    | Type[UnprocessableEntityErrorSpec]
+    | Type[TooManyRequestsErrorSpec]
+    | Type[InternalServerErrorSpec]
+    | Type[NotImplementedErrorSpec]
+    | Type[BadGatewayErrorSpec]
+    | Type[ServiceUnavailableErrorSpec]
+)
+AnyErrorSpec = (
+    BadRequestErrorSpec
+    | UnauthorizedErrorSpec
+    | ForbiddenErrorSpec
+    | NotFoundErrorSpec
+    | MethodNotAllowedErrorSpec
+    | ConflictErrorSpec
+    | UnprocessableEntityErrorSpec
+    | TooManyRequestsErrorSpec
+    | InternalServerErrorSpec
+    | NotImplementedErrorSpec
+    | BadGatewayErrorSpec
+    | ServiceUnavailableErrorSpec
+)
 
 
 class Factory:
@@ -192,12 +192,12 @@ class Factory:
     @overload
     @staticmethod
     def cls_from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorSpecType: ...
     @staticmethod
     def cls_from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorSpecType:
         if code is ErrorCode.BAD_REQUEST or code == 400:
@@ -301,12 +301,12 @@ class Factory:
     @overload
     @staticmethod
     def from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorSpec: ...
     @staticmethod
     def from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorSpec:
         return Factory.cls_from_code(code)()
