@@ -1,12 +1,12 @@
 import traceback as tb
 from fastapi.responses import JSONResponse
-from typing import Any, Generic, Literal, Type, Union, overload
+from typing import Any, Generic, Literal, Type, overload
 from uuid import uuid4
-from maleo.types.string import ListOfStrings, OptionalString
-from maleo.types.uuid import OptionalUUID
-from ..application import ApplicationContext, OptionalApplicationContext
-from ..connection import ConnectionContext, OptionalConnectionContext
-from ..error.enums import Code as ErrorCode
+from maleo.types.string import ListOfStrs, OptStr
+from maleo.types.uuid import OptUUID
+from ..application import ApplicationContext, OptApplicationContext
+from ..connection import ConnectionContext, OptConnectionContext
+from ..error.enums import ErrorCode
 from ..error.metadata import ErrorMetadata
 from ..error import (
     BadRequestError,
@@ -31,7 +31,7 @@ from ..operation.action.system import SystemOperationAction
 from ..operation.action.websocket import WebSocketOperationAction
 from ..operation.context import Context
 from ..operation.enums import OperationType
-from ..operation.mixins import Timestamp, OptionalTimestamp
+from ..operation.mixins import Timestamp, OptTimestamp
 from ..operation.request import (
     CreateFailedRequestOperation,
     ReadFailedRequestOperation,
@@ -48,7 +48,7 @@ from ..operation.resource import (
 )
 from ..operation.system import FailedSystemOperation
 from ..operation.websocket import FailedWebSocketOperation
-from ..resource import Resource, OptionalResource
+from ..resource import Resource, OptResource
 from ..response import (
     BadRequestResponse,
     UnauthorizedResponse,
@@ -62,13 +62,13 @@ from ..response import (
     NotImplementedResponse,
     BadGatewayResponse,
     ServiceUnavailableResponse,
-    OptionalAnyErrorResponse,
+    OptAnyErrorResponse,
     ErrorResponseT,
     ResponseContext,
 )
-from ..security.authentication import OptionalAnyAuthentication
-from ..security.authorization import OptionalAnyAuthorization
-from ..security.impersonation import OptionalImpersonation
+from ..security.authentication import OptAnyAuthentication
+from ..security.authorization import OptAnyAuthorization
+from ..security.impersonation import OptImpersonation
 
 
 class MaleoException(
@@ -87,17 +87,17 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.REQUEST],
-        application_context: OptionalApplicationContext = None,
-        operation_id: OptionalUUID = None,
+        application_context: OptApplicationContext = None,
+        operation_id: OptUUID = None,
         operation_context: Context,
         operation_action: AnyResourceOperationAction,
-        operation_timestamp: OptionalTimestamp = None,
-        operation_summary: OptionalString = None,
+        operation_timestamp: OptTimestamp = None,
+        operation_summary: OptStr = None,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: OptionalAnyErrorResponse = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: OptAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -105,18 +105,18 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.RESOURCE],
-        application_context: OptionalApplicationContext = None,
-        operation_id: OptionalUUID = None,
+        application_context: OptApplicationContext = None,
+        operation_id: OptUUID = None,
         operation_context: Context,
         operation_action: AnyResourceOperationAction,
         resource: Resource,
-        operation_timestamp: OptionalTimestamp = None,
-        operation_summary: OptionalString = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: OptionalAnyErrorResponse = None,
+        operation_timestamp: OptTimestamp = None,
+        operation_summary: OptStr = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: OptAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -124,18 +124,18 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.REQUEST, OperationType.RESOURCE],
-        application_context: OptionalApplicationContext = None,
-        operation_id: OptionalUUID = None,
+        application_context: OptApplicationContext = None,
+        operation_id: OptUUID = None,
         operation_context: Context,
         operation_action: AnyResourceOperationAction,
-        resource: OptionalResource = None,
-        operation_timestamp: OptionalTimestamp = None,
-        operation_summary: OptionalString = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: OptionalAnyErrorResponse = None,
+        resource: OptResource = None,
+        operation_timestamp: OptTimestamp = None,
+        operation_summary: OptStr = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: OptAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -143,17 +143,17 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.SYSTEM],
-        application_context: OptionalApplicationContext = None,
-        operation_id: OptionalUUID = None,
+        application_context: OptApplicationContext = None,
+        operation_id: OptUUID = None,
         operation_context: Context,
         operation_action: SystemOperationAction,
-        operation_timestamp: OptionalTimestamp = None,
-        operation_summary: OptionalString = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: OptionalAnyErrorResponse = None,
+        operation_timestamp: OptTimestamp = None,
+        operation_summary: OptStr = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: OptAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -161,17 +161,17 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.WEBSOCKET],
-        application_context: OptionalApplicationContext = None,
-        operation_id: OptionalUUID = None,
+        application_context: OptApplicationContext = None,
+        operation_id: OptUUID = None,
         operation_context: Context,
         operation_action: WebSocketOperationAction,
-        operation_timestamp: OptionalTimestamp = None,
-        operation_summary: OptionalString = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: OptionalAnyErrorResponse = None,
+        operation_timestamp: OptTimestamp = None,
+        operation_summary: OptStr = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: OptAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -179,44 +179,44 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: OperationType,
-        application_context: OptionalApplicationContext = None,
-        operation_id: OptionalUUID = None,
+        application_context: OptApplicationContext = None,
+        operation_id: OptUUID = None,
         operation_context: Context,
-        operation_action: Union[
-            AnyResourceOperationAction,
-            SystemOperationAction,
-            WebSocketOperationAction,
-        ],
-        resource: OptionalResource = None,
-        operation_timestamp: OptionalTimestamp = None,
-        operation_summary: OptionalString = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: OptionalAnyErrorResponse = None,
+        operation_action: (
+            AnyResourceOperationAction
+            | SystemOperationAction
+            | WebSocketOperationAction
+        ),
+        resource: OptResource = None,
+        operation_timestamp: OptTimestamp = None,
+        operation_summary: OptStr = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: OptAnyErrorResponse = None,
     ) -> None: ...
     def __init__(
         self,
         *args: object,
         details: Any = None,
         operation_type: OperationType,
-        application_context: OptionalApplicationContext = None,
-        operation_id: OptionalUUID = None,
+        application_context: OptApplicationContext = None,
+        operation_id: OptUUID = None,
         operation_context: Context,
-        operation_action: Union[
-            AnyResourceOperationAction,
-            SystemOperationAction,
-            WebSocketOperationAction,
-        ],
-        resource: OptionalResource = None,
-        operation_timestamp: OptionalTimestamp = None,
-        operation_summary: OptionalString = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: OptionalAnyErrorResponse = None,
+        operation_action: (
+            AnyResourceOperationAction
+            | SystemOperationAction
+            | WebSocketOperationAction
+        ),
+        resource: OptResource = None,
+        operation_timestamp: OptTimestamp = None,
+        operation_summary: OptStr = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: OptAnyErrorResponse = None,
     ) -> None:
         super().__init__(*args)
         self.details = details
@@ -262,52 +262,52 @@ class MaleoException(
         )
 
     @property
-    def traceback(self) -> ListOfStrings:
+    def traceback(self) -> ListOfStrs:
         return tb.format_exception(self)
 
     @property
-    def operation(self) -> Union[
+    def operation(self) -> (
         CreateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedRequestOperation[
+        ]
+        | ReadFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedRequestOperation[
+        ]
+        | UpdateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedRequestOperation[
+        ]
+        | DeleteFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        CreateFailedResourceOperation[
+        ]
+        | CreateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedResourceOperation[
+        ]
+        | ReadFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedResourceOperation[
+        ]
+        | UpdateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedResourceOperation[
+        ]
+        | DeleteFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        FailedSystemOperation[
+        ]
+        | FailedSystemOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        FailedWebSocketOperation[
+        ]
+        | FailedWebSocketOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]:
+        ]
+    ):
         if self.operation_type is OperationType.REQUEST:
             if not isinstance(self.operation_action, ResourceOperationActions):
                 raise ValueError(
@@ -433,47 +433,47 @@ class MaleoException(
         self,
         operation_type: Literal[OperationType.REQUEST],
         /,
-    ) -> Union[
+    ) -> (
         CreateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedRequestOperation[
+        ]
+        | ReadFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedRequestOperation[
+        ]
+        | UpdateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedRequestOperation[
+        ]
+        | DeleteFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]: ...
+        ]
+    ): ...
     @overload
     def generate_operation(
         self,
         operation_type: Literal[OperationType.RESOURCE],
         /,
-    ) -> Union[
+    ) -> (
         CreateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedResourceOperation[
+        ]
+        | ReadFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedResourceOperation[
+        ]
+        | UpdateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedResourceOperation[
+        ]
+        | DeleteFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]: ...
+        ]
+    ): ...
     @overload
     def generate_operation(
         self,
@@ -490,48 +490,48 @@ class MaleoException(
         self,
         operation_type: OperationType,
         /,
-    ) -> Union[
+    ) -> (
         CreateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedRequestOperation[
+        ]
+        | ReadFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedRequestOperation[
+        ]
+        | UpdateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedRequestOperation[
+        ]
+        | DeleteFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        CreateFailedResourceOperation[
+        ]
+        | CreateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedResourceOperation[
+        ]
+        | ReadFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedResourceOperation[
+        ]
+        | UpdateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedResourceOperation[
+        ]
+        | DeleteFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        FailedSystemOperation[
+        ]
+        | FailedSystemOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        FailedWebSocketOperation[
+        ]
+        | FailedWebSocketOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]:
+        ]
+    ):
         if operation_type != self.operation_type:
             raise ValueError(
                 ErrorCode.INTERNAL_SERVER_ERROR,
@@ -802,31 +802,31 @@ class ServiceUnavailable(
     response_cls = ServiceUnavailableResponse
 
 
-AnyExceptionType = Union[
-    Type[BadRequest],
-    Type[Unauthorized],
-    Type[Forbidden],
-    Type[NotFound],
-    Type[MethodNotAllowed],
-    Type[Conflict],
-    Type[UnprocessableEntity],
-    Type[TooManyRequests],
-    Type[InternalServerError],
-    Type[NotImplemented],
-    Type[BadGateway],
-    Type[ServiceUnavailable],
-]
-AnyException = Union[
-    BadRequest,
-    Unauthorized,
-    Forbidden,
-    NotFound,
-    MethodNotAllowed,
-    Conflict,
-    UnprocessableEntity,
-    TooManyRequests,
-    InternalServerError,
-    NotImplemented,
-    BadGateway,
-    ServiceUnavailable,
-]
+AnyExceptionType = (
+    Type[BadRequest]
+    | Type[Unauthorized]
+    | Type[Forbidden]
+    | Type[NotFound]
+    | Type[MethodNotAllowed]
+    | Type[Conflict]
+    | Type[UnprocessableEntity]
+    | Type[TooManyRequests]
+    | Type[InternalServerError]
+    | Type[NotImplemented]
+    | Type[BadGateway]
+    | Type[ServiceUnavailable]
+)
+AnyException = (
+    BadRequest
+    | Unauthorized
+    | Forbidden
+    | NotFound
+    | MethodNotAllowed
+    | Conflict
+    | UnprocessableEntity
+    | TooManyRequests
+    | InternalServerError
+    | NotImplemented
+    | BadGateway
+    | ServiceUnavailable
+)
