@@ -1,10 +1,10 @@
 import logging
-from typing import Union
 from fastapi import Request, Response, status
 from fastapi.encoders import jsonable_encoder
 from fastapi.exceptions import (
     HTTPException,
     RequestValidationError,
+    WebSocketRequestValidationError,
     ResponseValidationError,
 )
 from fastapi.requests import HTTPConnection
@@ -14,7 +14,7 @@ from starlette.authentication import AuthenticationError
 from maleo.logging.enums import Level, LoggerType
 from maleo.utils.exception import extract_details
 from ..error.constants import ERROR_CODE_STATUS_CODE_MAP
-from ..error.enums import Code as ErrorCode
+from ..error.enums import ErrorCode
 from ..response import (
     UnauthorizedResponse,
     UnprocessableEntityResponse,
@@ -37,11 +37,12 @@ def authentication_error_handler(
 
 async def validation_error_handler(
     request: Request,
-    exc: Union[
-        RequestValidationError,
-        ResponseValidationError,
-        ValidationError,
-    ],
+    exc: (
+        RequestValidationError
+        | WebSocketRequestValidationError
+        | ResponseValidationError
+        | ValidationError
+    ),
 ) -> JSONResponse:
     return JSONResponse(
         content=UnprocessableEntityResponse(
@@ -63,10 +64,10 @@ async def http_exception_handler(request: Request, exc: HTTPException) -> JSONRe
 
 
 async def maleo_exception_handler(
-    request: Request, exc: Union[MaleoException, AnyException]
+    request: Request, exc: MaleoException | AnyException
 ) -> JSONResponse:
     logger = logging.getLogger(
-        f"{exc.application_context.environment} - {exc.application_context.key} - {LoggerType.EXCEPTION}"
+        f"{exc.application_context.environment} - {exc.application_context.service_key} - {LoggerType.EXCEPTION}"
     )
 
     exc.operation.log(logger, Level.ERROR)
