@@ -6,67 +6,70 @@ from typing import (
     Callable,
     Literal,
     Mapping,
-    Optional,
     Type,
     TypeVar,
-    Union,
     overload,
 )
 from ..enums import (
     ResourceOperationType,
+    OptResourceOperationType,
     ResourceOperationCreateType,
+    OptResourceOperationCreateType,
     ResourceOperationUpdateType,
+    OptResourceOperationUpdateType,
     ResourceOperationDataUpdateType,
+    OptResourceOperationDataUpdateType,
     ResourceOperationStatusUpdateType,
+    OptResourceOperationStatusUpdateType,
 )
 from .base import BaseOperationAction
 
 
 class ResourceOperationAction(BaseOperationAction[ResourceOperationType]):
     create_type: Annotated[
-        Optional[ResourceOperationCreateType],
+        OptResourceOperationCreateType,
         Field(None, description="Resource operation's create type (optional)"),
     ] = None
     update_type: Annotated[
-        Optional[ResourceOperationUpdateType],
+        OptResourceOperationUpdateType,
         Field(None, description="Resource operation's update type (optional)"),
     ] = None
     data_update_type: Annotated[
-        Optional[ResourceOperationDataUpdateType],
+        OptResourceOperationDataUpdateType,
         Field(None, description="Resource operation's data update type (optional)"),
     ] = None
     status_update_type: Annotated[
-        Optional[ResourceOperationStatusUpdateType],
+        OptResourceOperationStatusUpdateType,
         Field(None, description="Resource operation's status update type (optional)"),
     ] = None
 
 
 class CreateResourceOperationAction(ResourceOperationAction):
     type: ResourceOperationType = ResourceOperationType.CREATE
-    update_type: Optional[ResourceOperationUpdateType] = None
-    data_update_type: Optional[ResourceOperationDataUpdateType] = None
-    status_update_type: Optional[ResourceOperationStatusUpdateType] = None
+    update_type: OptResourceOperationUpdateType = None
+    data_update_type: OptResourceOperationDataUpdateType = None
+    status_update_type: OptResourceOperationStatusUpdateType = None
 
 
 class ReadResourceOperationAction(ResourceOperationAction):
     type: ResourceOperationType = ResourceOperationType.READ
-    create_type: Optional[ResourceOperationCreateType] = None
-    update_type: Optional[ResourceOperationUpdateType] = None
-    data_update_type: Optional[ResourceOperationDataUpdateType] = None
-    status_update_type: Optional[ResourceOperationStatusUpdateType] = None
+    create_type: OptResourceOperationCreateType = None
+    update_type: OptResourceOperationUpdateType = None
+    data_update_type: OptResourceOperationDataUpdateType = None
+    status_update_type: OptResourceOperationStatusUpdateType = None
 
 
 class UpdateResourceOperationAction(ResourceOperationAction):
     type: ResourceOperationType = ResourceOperationType.UPDATE
-    create_type: Optional[ResourceOperationCreateType] = None
+    create_type: OptResourceOperationCreateType = None
 
 
 class DeleteResourceOperationAction(ResourceOperationAction):
     type: ResourceOperationType = ResourceOperationType.DELETE
-    create_type: Optional[ResourceOperationCreateType] = None
-    update_type: Optional[ResourceOperationUpdateType] = None
-    data_update_type: Optional[ResourceOperationDataUpdateType] = None
-    status_update_type: Optional[ResourceOperationStatusUpdateType] = None
+    create_type: OptResourceOperationCreateType = None
+    update_type: OptResourceOperationUpdateType = None
+    data_update_type: OptResourceOperationDataUpdateType = None
+    status_update_type: OptResourceOperationStatusUpdateType = None
 
 
 ResourceOperationActions = (
@@ -77,12 +80,12 @@ ResourceOperationActions = (
 )
 
 
-AnyResourceOperationAction = Union[
-    CreateResourceOperationAction,
-    ReadResourceOperationAction,
-    UpdateResourceOperationAction,
-    DeleteResourceOperationAction,
-]
+AnyResourceOperationAction = (
+    CreateResourceOperationAction
+    | ReadResourceOperationAction
+    | UpdateResourceOperationAction
+    | DeleteResourceOperationAction
+)
 
 
 AnyResourceOperationActionT = TypeVar(
@@ -90,6 +93,9 @@ AnyResourceOperationActionT = TypeVar(
 )
 
 
+OptAnyResourceOperationAction = AnyResourceOperationAction | None
+
+
 TYPE_ACTION_MODEL_MAP: Mapping[ResourceOperationType, Type] = {
     ResourceOperationType.CREATE: CreateResourceOperationAction,
     ResourceOperationType.READ: ReadResourceOperationAction,
@@ -104,7 +110,7 @@ class Factory:
     def generate(
         type_: Literal[ResourceOperationType.CREATE],
         *,
-        create_type: Optional[ResourceOperationCreateType] = ...,
+        create_type: OptResourceOperationCreateType = ...,
     ) -> CreateResourceOperationAction: ...
     @overload
     @staticmethod
@@ -117,9 +123,9 @@ class Factory:
     def generate(
         type_: Literal[ResourceOperationType.UPDATE],
         *,
-        update_type: Optional[ResourceOperationUpdateType] = ...,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = ...,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = ...,
+        update_type: OptResourceOperationUpdateType = ...,
+        data_update_type: OptResourceOperationDataUpdateType = ...,
+        status_update_type: OptResourceOperationStatusUpdateType = ...,
     ) -> UpdateResourceOperationAction: ...
     @overload
     @staticmethod
@@ -132,19 +138,19 @@ class Factory:
     def generate(
         type_: ResourceOperationType,
         *,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
     ) -> AnyResourceOperationAction: ...
     @staticmethod
     def generate(
         type_: ResourceOperationType,
         *,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
     ) -> AnyResourceOperationAction:
         if type_ is ResourceOperationType.CREATE:
             return CreateResourceOperationAction(create_type=create_type)
@@ -209,7 +215,7 @@ class Factory:
     @overload
     @staticmethod
     def extract(
-        type_: Optional[ResourceOperationType] = None,
+        type_: OptResourceOperationType = None,
         *,
         request: Request,
         from_state: bool = True,
@@ -217,7 +223,7 @@ class Factory:
     ) -> AnyResourceOperationAction: ...
     @staticmethod
     def extract(
-        type_: Optional[ResourceOperationType] = None,
+        type_: OptResourceOperationType = None,
         *,
         request: Request,
         from_state: bool = True,
@@ -361,7 +367,7 @@ class Factory:
     ) -> Callable[..., DeleteResourceOperationAction]: ...
     @staticmethod
     def as_dependency(
-        type_: Optional[ResourceOperationType] = None,
+        type_: OptResourceOperationType = None,
         *,
         from_state: bool = True,
         strict: bool = False,
