@@ -1,7 +1,7 @@
 from pydantic import BaseModel, Field
 from typing import Generic
-from maleo.types.dict import OptionalStringToAnyDict
-from maleo.types.enum import StringEnumT
+from maleo.types.dict import OptStrToAnyDict
+from maleo.types.enum import StrEnumT
 from .enums import (
     Origin as OriginEnum,
     Layer as LayerEnum,
@@ -9,9 +9,9 @@ from .enums import (
 )
 
 
-class Component(BaseModel, Generic[StringEnumT]):
-    type: StringEnumT = Field(..., description="Component's type")
-    details: OptionalStringToAnyDict = Field(None, description="Component's details")
+class Component(BaseModel, Generic[StrEnumT]):
+    type: StrEnumT = Field(..., description="Component's type")
+    details: OptStrToAnyDict = Field(None, description="Component's details")
 
 
 class Origin(Component[OriginEnum]):
@@ -57,9 +57,9 @@ def generate(
     origin: OriginEnum,
     layer: LayerEnum,
     target: TargetEnum = TargetEnum.INTERNAL,
-    origin_details: OptionalStringToAnyDict = None,
-    layer_details: OptionalStringToAnyDict = None,
-    target_details: OptionalStringToAnyDict = None,
+    origin_details: OptStrToAnyDict = None,
+    layer_details: OptStrToAnyDict = None,
+    target_details: OptStrToAnyDict = None,
 ) -> Context:
     return Context(
         origin=Origin(type=origin, details=origin_details),
