@@ -1,5 +1,5 @@
 from enum import StrEnum
-from maleo.types.string import ListOfStrings
+from maleo.types.string import ListOfStrs
 
 
 class IdSource(StrEnum):
@@ -7,7 +7,7 @@ class IdSource(StrEnum):
     STATE = "state"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
@@ -18,10 +18,13 @@ class OperationType(StrEnum):
     WEBSOCKET = "websocket"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptOperationType = OperationType | None
+
+
 class SystemOperationType(StrEnum):
     BACKGROUND_JOB = "background_job"
     CONFIGURATION_UPDATE = "configuration_update"
@@ -37,10 +40,13 @@ class SystemOperationType(StrEnum):
     SYSTEM_ALERT = "system_alert"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptSystemOperationType = SystemOperationType | None
+
+
 class WebSocketOperationType(StrEnum):
     CONNECT = "connect"
     DISCONNECT = "disconnect"
@@ -49,10 +55,13 @@ class WebSocketOperationType(StrEnum):
     SEND = "send"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptWebSocketOperationType = WebSocketOperationType | None
+
+
 class ResourceOperationType(StrEnum):
     CREATE = "create"
     READ = "read"
@@ -60,37 +69,49 @@ class ResourceOperationType(StrEnum):
     DELETE = "delete"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptResourceOperationType = ResourceOperationType | None
+
+
 class ResourceOperationCreateType(StrEnum):
     NEW = "new"
     RESTORE = "restore"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptResourceOperationCreateType = ResourceOperationCreateType | None
+
+
 class ResourceOperationUpdateType(StrEnum):
     DATA = "data"
     STATUS = "status"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptResourceOperationUpdateType = ResourceOperationUpdateType | None
+
+
 class ResourceOperationDataUpdateType(StrEnum):
     FULL = "full"
     PARTIAL = "partial"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptResourceOperationDataUpdateType = ResourceOperationDataUpdateType | None
+
+
 class ResourceOperationStatusUpdateType(StrEnum):
     ACTIVATE = "activate"
     DEACTIVATE = "deactivate"
@@ -98,20 +119,26 @@ class ResourceOperationStatusUpdateType(StrEnum):
     DELETE = "delete"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptResourceOperationStatusUpdateType = ResourceOperationStatusUpdateType | None
+
+
 class Origin(StrEnum):
     SERVICE = "service"
     CLIENT = "client"
     UTILITY = "utility"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptOrigin = Origin | None
+
+
 class Layer(StrEnum):
     INFRASTRUCTURE = "infrastructure"
     CONFIGURATION = "configuration"
@@ -124,10 +151,13 @@ class Layer(StrEnum):
     OTHER = "other"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
+OptLayer = Layer | None
+
+
 class Target(StrEnum):
     MONITORING = "monitoring"
     CACHE = "cache"
@@ -140,5 +170,8 @@ class Target(StrEnum):
     THIRD_PARTY = "third_party"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
+
+
+OptLayer = Layer | None
