@@ -1,20 +1,20 @@
 from copy import deepcopy
-from typing import Any, Generic, Literal, Optional, Type, Union, overload
+from typing import Any, Generic, Literal, Type, overload
 from uuid import UUID
-from maleo.types.boolean import BooleanT
+from maleo.types.boolean import BoolT
 from ..application import ApplicationContext
 from ..connection import ConnectionContext
-from ..error import OptionalAnyErrorT, AnyErrorT
-from ..pagination import OptionalAnyPagination
+from ..error import OptAnyErrorT, AnyErrorT
+from ..pagination import OptAnyPagination
 from ..response import (
     ResponseContext,
     ResponseT,
     ErrorResponseT,
     AnyDataResponse,
 )
-from ..security.authentication import OptionalAnyAuthentication
-from ..security.authorization import OptionalAnyAuthorization
-from ..security.impersonation import OptionalImpersonation
+from ..security.authentication import OptAnyAuthentication
+from ..security.authorization import OptAnyAuthorization
+from ..security.impersonation import OptImpersonation
 from .action.resource import (
     AnyResourceOperationActionT,
     CreateResourceOperationAction,
@@ -23,6 +23,7 @@ from .action.resource import (
     DeleteResourceOperationAction,
     ResourceOperationActions,
     AnyResourceOperationAction,
+    OptAnyResourceOperationAction,
     Factory as ResourceOperationActionFactory,
 )
 from .base import BaseOperation
@@ -30,10 +31,11 @@ from .context import Context as OperationContext
 from .enums import (
     OperationType,
     ResourceOperationType,
-    ResourceOperationCreateType,
-    ResourceOperationUpdateType,
-    ResourceOperationDataUpdateType,
-    ResourceOperationStatusUpdateType,
+    OptResourceOperationType,
+    OptResourceOperationCreateType,
+    OptResourceOperationUpdateType,
+    OptResourceOperationDataUpdateType,
+    OptResourceOperationStatusUpdateType,
 )
 from .mixins import Timestamp
 
@@ -42,16 +44,16 @@ class RequestOperation(
     BaseOperation[
         AnyResourceOperationActionT,
         None,
-        BooleanT,
-        OptionalAnyErrorT,
+        BoolT,
+        OptAnyErrorT,
         ConnectionContext,
         ResponseT,
         ResponseContext,
     ],
     Generic[
         AnyResourceOperationActionT,
-        BooleanT,
-        OptionalAnyErrorT,
+        BoolT,
+        OptAnyErrorT,
         ResponseT,
     ],
 ):
@@ -137,7 +139,7 @@ class SuccessfulRequestOperation(
         AnyResourceOperationActionT,
         Literal[True],
         None,
-        AnyDataResponse[Any, OptionalAnyPagination, Any],
+        AnyDataResponse[Any, OptAnyPagination, Any],
     ],
     Generic[AnyResourceOperationActionT],
 ):
@@ -170,20 +172,20 @@ class DeleteSuccessfulRequestOperation(
     pass
 
 
-AnySuccessfulRequestOperationType = Union[
-    Type[CreateSuccessfulRequestOperation],
-    Type[ReadSuccessfulRequestOperation],
-    Type[UpdateSuccessfulRequestOperation],
-    Type[DeleteSuccessfulRequestOperation],
-]
+AnySuccessfulRequestOperationType = (
+    Type[CreateSuccessfulRequestOperation]
+    | Type[ReadSuccessfulRequestOperation]
+    | Type[UpdateSuccessfulRequestOperation]
+    | Type[DeleteSuccessfulRequestOperation]
+)
 
 
-AnySuccessfulRequestOperation = Union[
-    CreateSuccessfulRequestOperation,
-    ReadSuccessfulRequestOperation,
-    UpdateSuccessfulRequestOperation,
-    DeleteSuccessfulRequestOperation,
-]
+AnySuccessfulRequestOperation = (
+    CreateSuccessfulRequestOperation
+    | ReadSuccessfulRequestOperation
+    | UpdateSuccessfulRequestOperation
+    | DeleteSuccessfulRequestOperation
+)
 
 
 class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
@@ -221,59 +223,59 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
     ]: ...
     @overload
     @classmethod
-    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> Union[
+    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> (
         Type[
             CreateFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             ReadFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             UpdateFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             DeleteFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-    ]: ...
+        ]
+    ): ...
     @classmethod
-    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> Union[
+    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> (
         Type[
             CreateFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             ReadFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             UpdateFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             DeleteFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-    ]:
+        ]
+    ):
         if isinstance(action, CreateResourceOperationAction):
             operation_cls = CreateFailedRequestOperation[
                 AnyErrorT,
@@ -344,32 +346,32 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
     def operation_cls_from_type(
         cls,
         type_: ResourceOperationType,
-    ) -> Union[
+    ) -> (
         Type[
             CreateFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             ReadFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             UpdateFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             DeleteFailedRequestOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-    ]:
+        ]
+    ):
         if type_ is ResourceOperationType.CREATE:
             operation_cls = CreateFailedRequestOperation[
                 AnyErrorT,
@@ -405,9 +407,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> CreateFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -424,9 +426,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> ReadFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -443,9 +445,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> UpdateFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -462,9 +464,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> DeleteFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -481,36 +483,36 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
-    ) -> Union[
+    ) -> (
         CreateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedRequestOperation[
+        ]
+        | ReadFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedRequestOperation[
+        ]
+        | UpdateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedRequestOperation[
+        ]
+        | DeleteFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]: ...
+        ]
+    ): ...
     @overload
     @classmethod
     def generate(
         cls,
         *,
         type_: Literal[ResourceOperationType.CREATE],
-        create_type: Optional[ResourceOperationCreateType] = ...,
+        create_type: OptResourceOperationCreateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -518,9 +520,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> CreateFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -537,9 +539,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> ReadFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -549,9 +551,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: Literal[ResourceOperationType.UPDATE],
-        update_type: Optional[ResourceOperationUpdateType] = ...,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = ...,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = ...,
+        update_type: OptResourceOperationUpdateType = ...,
+        data_update_type: OptResourceOperationDataUpdateType = ...,
+        status_update_type: OptResourceOperationStatusUpdateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -559,9 +561,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> UpdateFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -578,9 +580,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
     ) -> DeleteFailedRequestOperation[AnyErrorT, ErrorResponseT]: ...
@@ -590,10 +592,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: ResourceOperationType,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -601,39 +603,39 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
-    ) -> Union[
+    ) -> (
         CreateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedRequestOperation[
+        ]
+        | ReadFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedRequestOperation[
+        ]
+        | UpdateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedRequestOperation[
+        ]
+        | DeleteFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]: ...
+        ]
+    ): ...
     @classmethod
     def generate(
         cls,
-        action: Optional[AnyResourceOperationAction] = None,
+        action: OptAnyResourceOperationAction = None,
         *,
-        type_: Optional[ResourceOperationType] = None,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        type_: OptResourceOperationType = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -641,29 +643,29 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         summary: str,
         error: AnyErrorT,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
         response_context: ResponseContext,
-    ) -> Union[
+    ) -> (
         CreateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedRequestOperation[
+        ]
+        | ReadFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedRequestOperation[
+        ]
+        | UpdateFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedRequestOperation[
+        ]
+        | DeleteFailedRequestOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]:
+        ]
+    ):
         if (action is None and type_ is None) or (
             action is not None and type_ is not None
         ):
@@ -801,10 +803,10 @@ class SuccessfulFactory:
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> CreateSuccessfulRequestOperation: ...
     @overload
@@ -819,10 +821,10 @@ class SuccessfulFactory:
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> ReadSuccessfulRequestOperation: ...
     @overload
@@ -837,10 +839,10 @@ class SuccessfulFactory:
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> UpdateSuccessfulRequestOperation: ...
     @overload
@@ -855,10 +857,10 @@ class SuccessfulFactory:
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> DeleteSuccessfulRequestOperation: ...
     @overload
@@ -873,34 +875,29 @@ class SuccessfulFactory:
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
-    ) -> Union[
-        CreateSuccessfulRequestOperation,
-        ReadSuccessfulRequestOperation,
-        UpdateSuccessfulRequestOperation,
-        DeleteSuccessfulRequestOperation,
-    ]: ...
+    ) -> AnySuccessfulRequestOperation: ...
     @overload
     @classmethod
     def generate(
         cls,
         *,
         type_: Literal[ResourceOperationType.CREATE],
-        create_type: Optional[ResourceOperationCreateType] = ...,
+        create_type: OptResourceOperationCreateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> CreateSuccessfulRequestOperation: ...
     @overload
@@ -915,10 +912,10 @@ class SuccessfulFactory:
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> ReadSuccessfulRequestOperation: ...
     @overload
@@ -927,19 +924,19 @@ class SuccessfulFactory:
         cls,
         *,
         type_: Literal[ResourceOperationType.UPDATE],
-        update_type: Optional[ResourceOperationUpdateType] = ...,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = ...,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = ...,
+        update_type: OptResourceOperationUpdateType = ...,
+        data_update_type: OptResourceOperationDataUpdateType = ...,
+        status_update_type: OptResourceOperationStatusUpdateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> UpdateSuccessfulRequestOperation: ...
     @overload
@@ -954,10 +951,10 @@ class SuccessfulFactory:
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> DeleteSuccessfulRequestOperation: ...
     @overload
@@ -966,42 +963,42 @@ class SuccessfulFactory:
         cls,
         *,
         type_: ResourceOperationType,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> AnySuccessfulRequestOperation: ...
     @classmethod
     def generate(
         cls,
-        action: Optional[AnyResourceOperationAction] = None,
+        action: OptAnyResourceOperationAction = None,
         *,
-        type_: Optional[ResourceOperationType] = None,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        type_: OptResourceOperationType = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        response: AnyDataResponse[Any, OptionalAnyPagination, Any],
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        response: AnyDataResponse[Any, OptAnyPagination, Any],
         response_context: ResponseContext,
     ) -> AnySuccessfulRequestOperation:
         if (action is None and type_ is None) or (
