@@ -1,11 +1,11 @@
 from copy import deepcopy
-from typing import Generic, Literal, Optional, Type, Union, overload
+from typing import Generic, Literal, Type, overload
 from uuid import UUID
-from maleo.types.boolean import BooleanT
+from maleo.types.boolean import BoolT
 from ..application import ApplicationContext
-from ..connection import OptionalConnectionContext
+from ..connection import OptConnectionContext
 from ..data import ModelDataT
-from ..error import OptionalAnyErrorT, AnyErrorT
+from ..error import OptAnyErrorT, AnyErrorT
 from ..metadata import ModelMetadataT
 from ..pagination import PaginationT
 from ..resource import Resource
@@ -23,9 +23,9 @@ from ..response import (
     UpdateMultipleDataResponse,
     DeleteMultipleDataResponse,
 )
-from ..security.authentication import OptionalAnyAuthentication
-from ..security.authorization import OptionalAnyAuthorization
-from ..security.impersonation import OptionalImpersonation
+from ..security.authentication import OptAnyAuthentication
+from ..security.authorization import OptAnyAuthorization
+from ..security.impersonation import OptImpersonation
 from .action.resource import (
     AnyResourceOperationActionT,
     CreateResourceOperationAction,
@@ -34,6 +34,7 @@ from .action.resource import (
     DeleteResourceOperationAction,
     ResourceOperationActions,
     AnyResourceOperationAction,
+    OptAnyResourceOperationAction,
     Factory as ResourceOperationActionFactory,
 )
 from .base import BaseOperation
@@ -41,10 +42,11 @@ from .context import Context as OperationContext
 from .enums import (
     OperationType,
     ResourceOperationType,
-    ResourceOperationCreateType,
-    ResourceOperationUpdateType,
-    ResourceOperationDataUpdateType,
-    ResourceOperationStatusUpdateType,
+    OptResourceOperationType,
+    OptResourceOperationCreateType,
+    OptResourceOperationUpdateType,
+    OptResourceOperationDataUpdateType,
+    OptResourceOperationStatusUpdateType,
 )
 from .mixins import Timestamp
 
@@ -53,16 +55,16 @@ class ResourceOperation(
     BaseOperation[
         AnyResourceOperationActionT,
         Resource,
-        BooleanT,
-        OptionalAnyErrorT,
-        OptionalConnectionContext,
+        BoolT,
+        OptAnyErrorT,
+        OptConnectionContext,
         ResponseT,
         None,
     ],
     Generic[
         AnyResourceOperationActionT,
-        BooleanT,
-        OptionalAnyErrorT,
+        BoolT,
+        OptAnyErrorT,
         ResponseT,
     ],
 ):
@@ -314,59 +316,59 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
     ]: ...
     @overload
     @classmethod
-    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> Union[
+    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> (
         Type[
             CreateFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             ReadFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             UpdateFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             DeleteFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-    ]: ...
+        ]
+    ): ...
     @classmethod
-    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> Union[
+    def operation_cls_from_action(cls, action: AnyResourceOperationAction) -> (
         Type[
             CreateFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             ReadFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             UpdateFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             DeleteFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-    ]:
+        ]
+    ):
         if isinstance(action, CreateResourceOperationAction):
             operation_cls = CreateFailedResourceOperation[
                 AnyErrorT,
@@ -437,32 +439,32 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
     def operation_cls_from_type(
         cls,
         type_: ResourceOperationType,
-    ) -> Union[
+    ) -> (
         Type[
             CreateFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             ReadFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             UpdateFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-        Type[
+        ]
+        | Type[
             DeleteFailedResourceOperation[
                 AnyErrorT,
                 ErrorResponseT,
             ]
-        ],
-    ]:
+        ]
+    ):
         if type_ is ResourceOperationType.CREATE:
             operation_cls = CreateFailedResourceOperation[
                 AnyErrorT,
@@ -498,10 +500,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> CreateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -517,10 +519,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> ReadFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -536,10 +538,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> UpdateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -555,10 +557,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> DeleteFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -574,36 +576,36 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
-    ) -> Union[
+    ) -> (
         CreateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedResourceOperation[
+        ]
+        | ReadFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedResourceOperation[
+        ]
+        | UpdateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedResourceOperation[
+        ]
+        | DeleteFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]: ...
+        ]
+    ): ...
     @overload
     @classmethod
     def generate(
         cls,
         *,
         type_: Literal[ResourceOperationType.CREATE],
-        create_type: Optional[ResourceOperationCreateType] = ...,
+        create_type: OptResourceOperationCreateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -611,10 +613,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> CreateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -630,10 +632,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> ReadFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -642,9 +644,9 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: Literal[ResourceOperationType.UPDATE],
-        update_type: Optional[ResourceOperationUpdateType] = ...,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = ...,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = ...,
+        update_type: OptResourceOperationUpdateType = ...,
+        data_update_type: OptResourceOperationDataUpdateType = ...,
+        status_update_type: OptResourceOperationStatusUpdateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -652,10 +654,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> UpdateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -671,10 +673,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
     ) -> DeleteFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
@@ -683,10 +685,10 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: ResourceOperationType,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -694,39 +696,39 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
-    ) -> Union[
+    ) -> (
         CreateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedResourceOperation[
+        ]
+        | ReadFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedResourceOperation[
+        ]
+        | UpdateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedResourceOperation[
+        ]
+        | DeleteFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]: ...
+        ]
+    ): ...
     @classmethod
     def generate(
         cls,
-        action: Optional[AnyResourceOperationAction] = None,
+        action: OptAnyResourceOperationAction = None,
         *,
-        type_: Optional[ResourceOperationType] = None,
-        create_type: Optional[ResourceOperationCreateType] = None,
-        update_type: Optional[ResourceOperationUpdateType] = None,
-        data_update_type: Optional[ResourceOperationDataUpdateType] = None,
-        status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
+        type_: OptResourceOperationType = None,
+        create_type: OptResourceOperationCreateType = None,
+        update_type: OptResourceOperationUpdateType = None,
+        data_update_type: OptResourceOperationDataUpdateType = None,
+        status_update_type: OptResourceOperationStatusUpdateType = None,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -734,29 +736,29 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
         response: ErrorResponseT,
-    ) -> Union[
+    ) -> (
         CreateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        ReadFailedResourceOperation[
+        ]
+        | ReadFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        UpdateFailedResourceOperation[
+        ]
+        | UpdateFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-        DeleteFailedResourceOperation[
+        ]
+        | DeleteFailedResourceOperation[
             AnyErrorT,
             ErrorResponseT,
-        ],
-    ]:
+        ]
+    ):
         if (action is None and type_ is None) or (
             action is not None and type_ is not None
         ):
