@@ -1,8 +1,8 @@
 from typing import Generic, Literal
-from maleo.types.boolean import BooleanT
-from ..connection import OptionalConnectionContext
+from maleo.types.boolean import BoolT
+from ..connection import OptConnectionContext
 from ..error import (
-    OptionalAnyErrorT,
+    OptAnyErrorT,
     AnyErrorT,
 )
 from ..response import ResponseT, ErrorResponseT, SuccessResponseT
@@ -15,15 +15,15 @@ class SystemOperation(
     BaseOperation[
         SystemOperationAction,
         None,
-        BooleanT,
-        OptionalAnyErrorT,
-        OptionalConnectionContext,
+        BoolT,
+        OptAnyErrorT,
+        OptConnectionContext,
         ResponseT,
         None,
     ],
     Generic[
-        BooleanT,
-        OptionalAnyErrorT,
+        BoolT,
+        OptAnyErrorT,
         ResponseT,
     ],
 ):
