@@ -1,45 +1,48 @@
 from pydantic import Field
 from typing import Annotated, Generic
-from maleo.enums.status import ListOfDataStatuses, FULL_DATA_STATUSES
-from maleo.types.enum import StringEnumT
+from maleo.enums.status import (
+    ListOfDataStatuses,
+    SimpleDataStatusesMixin,
+    FULL_DATA_STATUSES,
+)
+from maleo.types.enum import StrEnumT
 from .mixins.filter import DateFilters
 from .mixins.identity import (
     IdentifierValueT,
-    IdentifierTypeValue,
+    IdentifierMixin,
 )
 from .mixins.parameter import (
     Search,
     UseCache,
 )
 from .mixins.sort import SortColumns
-from .mixins.status import DataStatuses
 from .operation.action.status import StatusUpdateOperationAction
 from .pagination import BaseFlexiblePagination, BaseStrictPagination
 
 
 class ReadSingleParameter(
-    DataStatuses[ListOfDataStatuses],
+    SimpleDataStatusesMixin[ListOfDataStatuses],
     UseCache,
-    IdentifierTypeValue[StringEnumT, IdentifierValueT],
-    Generic[StringEnumT, IdentifierValueT],
+    IdentifierMixin[StrEnumT, IdentifierValueT],
+    Generic[StrEnumT, IdentifierValueT],
 ):
     statuses: Annotated[
         ListOfDataStatuses,
-        Field(list(FULL_DATA_STATUSES), description="Data statuses", min_length=1),
-    ] = list(FULL_DATA_STATUSES)
+        Field(FULL_DATA_STATUSES, description="Data statuses", min_length=1),
+    ] = FULL_DATA_STATUSES
 
 
 class BaseReadMultipleParameter(
     SortColumns,
     Search,
-    DataStatuses[ListOfDataStatuses],
+    SimpleDataStatusesMixin[ListOfDataStatuses],
     DateFilters,
     UseCache,
 ):
     statuses: Annotated[
         ListOfDataStatuses,
-        Field(list(FULL_DATA_STATUSES), description="Data statuses", min_length=1),
-    ] = list(FULL_DATA_STATUSES)
+        Field(FULL_DATA_STATUSES, description="Data statuses", min_length=1),
+    ] = FULL_DATA_STATUSES
 
 
 class ReadUnpaginatedMultipleParameter(
@@ -58,14 +61,14 @@ class ReadPaginatedMultipleParameter(
 
 class StatusUpdateParameter(
     StatusUpdateOperationAction,
-    IdentifierTypeValue[StringEnumT, IdentifierValueT],
-    Generic[StringEnumT, IdentifierValueT],
+    IdentifierMixin[StrEnumT, IdentifierValueT],
+    Generic[StrEnumT, IdentifierValueT],
 ):
     pass
 
 
 class DeleteSingleParameter(
-    IdentifierTypeValue[StringEnumT, IdentifierValueT],
-    Generic[StringEnumT, IdentifierValueT],
+    IdentifierMixin[StrEnumT, IdentifierValueT],
+    Generic[StrEnumT, IdentifierValueT],
 ):
     pass
