@@ -2,21 +2,16 @@ from pydantic import BaseModel, Field
 from typing import (
     Annotated,
     Any,
-    Dict,
     Generic,
-    List,
     Literal,
-    Optional,
-    Tuple,
     Type,
     TypeVar,
-    Union,
     overload,
 )
-from maleo.types.boolean import BooleanT
-from maleo.types.dict import StringToAnyDict
-from maleo.types.misc import StringOrStringEnumT
-from maleo.types.string import OptionalString
+from maleo.types.boolean import BoolT
+from maleo.types.dict import StrToAnyDict
+from maleo.types.misc import IntOrStr, StrOrStrEnumT
+from maleo.types.string import OptStr, OptListOfDoubleStrs
 from .data import DataPair, AnyDataT, ModelDataT
 from .error.descriptor import (
     ErrorDescriptor,
@@ -33,10 +28,10 @@ from .error.descriptor import (
     BadGatewayErrorDescriptor,
     ServiceUnavailableErrorDescriptor,
 )
-from .error.enums import Code as ErrorCode
+from .error.enums import ErrorCode
 from .metadata import AnyMetadataT, ModelMetadataT
 from .mixins.general import Success, Descriptor
-from .pagination import OptionalPaginationT, PaginationT
+from .pagination import OptPaginationT, PaginationT
 from .payload import (
     Payload,
     NoDataPayload,
@@ -45,66 +40,65 @@ from .payload import (
     ReadSingleDataPayload,
     UpdateSingleDataPayload,
     DeleteSingleDataPayload,
-    OptionalSingleDataPayload,
+    OptSingleDataPayload,
     MultipleDataPayload,
     CreateMultipleDataPayload,
     ReadMultipleDataPayload,
     UpdateMultipleDataPayload,
     DeleteMultipleDataPayload,
-    OptionalMultipleDataPayload,
+    OptMultipleDataPayload,
 )
 from .success.descriptor import (
     SuccessDescriptor,
     AnyDataSuccessDescriptor,
     NoDataSuccessDescriptor,
     SingleDataSuccessDescriptor,
-    OptionalSingleDataSuccessDescriptor,
+    OptSingleDataSuccessDescriptor,
     CreateSingleDataSuccessDescriptor,
     ReadSingleDataSuccessDescriptor,
     UpdateSingleDataSuccessDescriptor,
     DeleteSingleDataSuccessDescriptor,
     MultipleDataSuccessDescriptor,
-    OptionalMultipleDataSuccessDescriptor,
+    OptMultipleDataSuccessDescriptor,
     CreateMultipleDataSuccessDescriptor,
     ReadMultipleDataSuccessDescriptor,
     UpdateMultipleDataSuccessDescriptor,
     DeleteMultipleDataSuccessDescriptor,
 )
-from .success.enums import Code as SuccessCode
+from .success.enums import SuccessCode
 
 
 class ResponseContext(BaseModel):
     status_code: Annotated[int, Field(..., description="Status code")]
-    media_type: Annotated[
-        OptionalString, Field(None, description="Media type (Optional)")
-    ] = None
-    headers: Annotated[
-        Optional[List[Tuple[str, str]]], Field(None, description="Response's headers")
-    ] = None
-
-
-OptionalResponseContext = Optional[ResponseContext]
-OptionalResponseContextT = TypeVar(
-    "OptionalResponseContextT", bound=Optional[OptionalResponseContext]
-)
-
-
-class ResponseContextMixin(BaseModel, Generic[OptionalResponseContextT]):
-    response_context: OptionalResponseContextT = Field(
-        ..., description="Response's context"
+    media_type: Annotated[OptStr, Field(None, description="Media type (Optional)")] = (
+        None
     )
+    headers: Annotated[
+        OptListOfDoubleStrs, Field(None, description="Response's headers")
+    ] = None
+
+
+OptResponseContext = ResponseContext | None
+OptResponseContextT = TypeVar("OptResponseContextT", bound=OptResponseContext)
+
+
+class ResponseContextMixin(BaseModel, Generic[OptResponseContextT]):
+    response_context: OptResponseContextT = Field(..., description="Response's context")
 
 
 class Response(
-    Payload[AnyDataT, OptionalPaginationT, AnyMetadataT],
-    Descriptor[StringOrStringEnumT],
-    Success[BooleanT],
+    Payload[AnyDataT, OptPaginationT, AnyMetadataT],
+    Descriptor[StrOrStrEnumT],
+    Success[BoolT],
     BaseModel,
-    Generic[BooleanT, StringOrStringEnumT, AnyDataT, OptionalPaginationT, AnyMetadataT],
+    Generic[BoolT, StrOrStrEnumT, AnyDataT, OptPaginationT, AnyMetadataT],
 ):
     pass
 
 
+OptResponse = Response | None
+
+
 # Error Response
 class ErrorResponse(
     NoDataPayload[None],
@@ -118,6 +112,9 @@ class ErrorResponse(
     other: Any = "Please try again later or contact administrator"
 
 
+OptErrorResponse = ErrorResponse | None
+
+
 class BadRequestResponse(
     BadRequestErrorDescriptor,
     ErrorResponse,
@@ -125,6 +122,9 @@ class BadRequestResponse(
     pass
 
 
+OptBadRequestResponse = BadRequestResponse | None
+
+
 class UnauthorizedResponse(
     UnauthorizedErrorDescriptor,
     ErrorResponse,
@@ -132,6 +132,9 @@ class UnauthorizedResponse(
     pass
 
 
+OptUnauthorizedResponse = UnauthorizedResponse | None
+
+
 class ForbiddenResponse(
     ForbiddenErrorDescriptor,
     ErrorResponse,
@@ -139,6 +142,9 @@ class ForbiddenResponse(
     pass
 
 
+OptForbiddenResponse = ForbiddenResponse | None
+
+
 class NotFoundResponse(
     NotFoundErrorDescriptor,
     ErrorResponse,
@@ -146,6 +152,9 @@ class NotFoundResponse(
     pass
 
 
+OptNotFoundResponse = NotFoundResponse | None
+
+
 class MethodNotAllowedResponse(
     MethodNotAllowedErrorDescriptor,
     ErrorResponse,
@@ -153,6 +162,9 @@ class MethodNotAllowedResponse(
     pass
 
 
+OptMethodNotAllowedResponse = MethodNotAllowedResponse | None
+
+
 class ConflictResponse(
     ConflictErrorDescriptor,
     ErrorResponse,
@@ -160,6 +172,9 @@ class ConflictResponse(
     pass
 
 
+OptConflictResponse = ConflictResponse | None
+
+
 class UnprocessableEntityResponse(
     UnprocessableEntityErrorDescriptor,
     ErrorResponse,
@@ -167,6 +182,9 @@ class UnprocessableEntityResponse(
     pass
 
 
+OptUnprocessableEntityResponse = UnprocessableEntityResponse | None
+
+
 class TooManyRequestsResponse(
     TooManyRequestsErrorDescriptor,
     ErrorResponse,
@@ -174,6 +192,9 @@ class TooManyRequestsResponse(
     pass
 
 
+OptTooManyRequestsResponse = TooManyRequestsResponse | None
+
+
 class InternalServerErrorResponse(
     InternalServerErrorDescriptor,
     ErrorResponse,
@@ -181,6 +202,9 @@ class InternalServerErrorResponse(
     pass
 
 
+OptInternalServerErrorResponse = InternalServerErrorResponse | None
+
+
 class NotImplementedResponse(
     NotImplementedErrorDescriptor,
     ErrorResponse,
@@ -188,6 +212,9 @@ class NotImplementedResponse(
     pass
 
 
+OptNotImplementedResponse = NotImplementedResponse | None
+
+
 class BadGatewayResponse(
     BadGatewayErrorDescriptor,
     ErrorResponse,
@@ -195,6 +222,9 @@ class BadGatewayResponse(
     pass
 
 
+OptBadGatewayResponse = BadGatewayResponse | None
+
+
 class ServiceUnavailableResponse(
     ServiceUnavailableErrorDescriptor,
     ErrorResponse,
@@ -202,36 +232,39 @@ class ServiceUnavailableResponse(
     pass
 
 
-AnyErrorResponseType = Union[
-    Type[BadRequestResponse],
-    Type[UnauthorizedResponse],
-    Type[ForbiddenResponse],
-    Type[NotFoundResponse],
-    Type[MethodNotAllowedResponse],
-    Type[ConflictResponse],
-    Type[UnprocessableEntityResponse],
-    Type[TooManyRequestsResponse],
-    Type[InternalServerErrorResponse],
-    Type[NotImplementedResponse],
-    Type[BadGatewayResponse],
-    Type[ServiceUnavailableResponse],
-]
-AnyErrorResponse = Union[
-    BadRequestResponse,
-    UnauthorizedResponse,
-    ForbiddenResponse,
-    NotFoundResponse,
-    MethodNotAllowedResponse,
-    ConflictResponse,
-    UnprocessableEntityResponse,
-    TooManyRequestsResponse,
-    InternalServerErrorResponse,
-    NotImplementedResponse,
-    BadGatewayResponse,
-    ServiceUnavailableResponse,
-]
+OptServiceUnavailableResponse = ServiceUnavailableResponse | None
+
+
+AnyErrorResponseType = (
+    Type[BadRequestResponse]
+    | Type[UnauthorizedResponse]
+    | Type[ForbiddenResponse]
+    | Type[NotFoundResponse]
+    | Type[MethodNotAllowedResponse]
+    | Type[ConflictResponse]
+    | Type[UnprocessableEntityResponse]
+    | Type[TooManyRequestsResponse]
+    | Type[InternalServerErrorResponse]
+    | Type[NotImplementedResponse]
+    | Type[BadGatewayResponse]
+    | Type[ServiceUnavailableResponse]
+)
+AnyErrorResponse = (
+    BadRequestResponse
+    | UnauthorizedResponse
+    | ForbiddenResponse
+    | NotFoundResponse
+    | MethodNotAllowedResponse
+    | ConflictResponse
+    | UnprocessableEntityResponse
+    | TooManyRequestsResponse
+    | InternalServerErrorResponse
+    | NotImplementedResponse
+    | BadGatewayResponse
+    | ServiceUnavailableResponse
+)
 ErrorResponseT = TypeVar("ErrorResponseT", bound=AnyErrorResponse)
-OptionalAnyErrorResponse = Optional[AnyErrorResponse]
+OptAnyErrorResponse = AnyErrorResponse | None
 
 
 class ErrorFactory:
@@ -310,12 +343,12 @@ class ErrorFactory:
     @overload
     @staticmethod
     def cls_from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorResponseType: ...
     @staticmethod
     def cls_from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         /,
     ) -> AnyErrorResponseType:
         if code is ErrorCode.BAD_REQUEST or code == 400:
@@ -349,8 +382,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.BAD_REQUEST, 400],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> BadRequestResponse: ...
     @overload
@@ -358,8 +391,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.UNAUTHORIZED, 401],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> UnauthorizedResponse: ...
     @overload
@@ -367,8 +400,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.FORBIDDEN, 403],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> ForbiddenResponse: ...
     @overload
@@ -376,8 +409,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.NOT_FOUND, 404],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> NotFoundResponse: ...
     @overload
@@ -385,8 +418,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.METHOD_NOT_ALLOWED, 405],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> MethodNotAllowedResponse: ...
     @overload
@@ -394,8 +427,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.CONFLICT, 409],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> ConflictResponse: ...
     @overload
@@ -403,8 +436,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.UNPROCESSABLE_ENTITY, 422],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> UnprocessableEntityResponse: ...
     @overload
@@ -412,8 +445,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.TOO_MANY_REQUESTS, 429],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> TooManyRequestsResponse: ...
     @overload
@@ -421,8 +454,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.INTERNAL_SERVER_ERROR, 500],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> InternalServerErrorResponse: ...
     @overload
@@ -430,8 +463,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.NOT_IMPLEMENTED, 501],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> NotImplementedResponse: ...
     @overload
@@ -439,8 +472,8 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.BAD_GATEWAY, 502],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> BadGatewayResponse: ...
     @overload
@@ -448,25 +481,25 @@ class ErrorFactory:
     def from_code(
         code: Literal[ErrorCode.SERVICE_UNAVAILABLE, 503],
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> ServiceUnavailableResponse: ...
     @overload
     @staticmethod
     def from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> AnyErrorResponse: ...
     @staticmethod
     def from_code(
-        code: Union[ErrorCode, int],
+        code: ErrorCode | int,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         other: Any = None,
     ) -> AnyErrorResponse:
         obj = {}
@@ -479,9 +512,9 @@ class ErrorFactory:
         return ErrorFactory.cls_from_code(code).model_validate(obj)
 
 
-OTHER_RESPONSES: Dict[
-    Union[int, str],
-    StringToAnyDict,
+OTHER_RESPONSES: dict[
+    IntOrStr,
+    StrToAnyDict,
 ] = {
     400: {
         "description": "Bad Request Response",
@@ -536,16 +569,16 @@ OTHER_RESPONSES: Dict[
 
 class SuccessResponse(
     SuccessDescriptor,
-    Response[Literal[True], SuccessCode, AnyDataT, OptionalPaginationT, AnyMetadataT],
-    Generic[AnyDataT, OptionalPaginationT, AnyMetadataT],
+    Response[Literal[True], SuccessCode, AnyDataT, OptPaginationT, AnyMetadataT],
+    Generic[AnyDataT, OptPaginationT, AnyMetadataT],
 ):
     success: Literal[True] = True
 
 
 class AnyDataResponse(
     AnyDataSuccessDescriptor,
-    SuccessResponse[AnyDataT, OptionalPaginationT, AnyMetadataT],
-    Generic[AnyDataT, OptionalPaginationT, AnyMetadataT],
+    SuccessResponse[AnyDataT, OptPaginationT, AnyMetadataT],
+    Generic[AnyDataT, OptPaginationT, AnyMetadataT],
 ):
     pass
 
@@ -563,8 +596,8 @@ class NoDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         metadata: ModelMetadataT = None,
         other: Any = None,
     ) -> "NoDataResponse[ModelMetadataT]":
@@ -591,8 +624,8 @@ class SingleDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         data: ModelDataT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -621,8 +654,8 @@ class CreateSingleDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         data: ModelDataT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -654,8 +687,8 @@ class ReadSingleDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         data: ModelDataT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -687,8 +720,8 @@ class UpdateSingleDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         old_data: ModelDataT,
         new_data: ModelDataT,
         metadata: ModelMetadataT = None,
@@ -721,8 +754,8 @@ class DeleteSingleDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
+        message: OptStr = None,
+        description: OptStr = None,
         data: ModelDataT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -742,10 +775,10 @@ class DeleteSingleDataResponse(
         )
 
 
-class OptionalSingleDataResponse(
-    OptionalSingleDataPayload[ModelDataT, ModelMetadataT],
-    OptionalSingleDataSuccessDescriptor,
-    SuccessResponse[Optional[ModelDataT], None, ModelMetadataT],
+class OptSingleDataResponse(
+    OptSingleDataPayload[ModelDataT, ModelMetadataT],
+    OptSingleDataSuccessDescriptor,
+    SuccessResponse[ModelDataT | None, None, ModelMetadataT],
     Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
@@ -754,13 +787,13 @@ class OptionalSingleDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
-        data: Optional[ModelDataT] = None,
+        message: OptStr = None,
+        description: OptStr = None,
+        data: ModelDataT | None = None,
         metadata: ModelMetadataT = None,
         other: Any = None,
-    ) -> "OptionalSingleDataResponse[ModelDataT, ModelMetadataT]":
-        descriptor = OptionalSingleDataSuccessDescriptor()
+    ) -> "OptSingleDataResponse[ModelDataT, ModelMetadataT]":
+        descriptor = OptSingleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
@@ -775,16 +808,16 @@ class OptionalSingleDataResponse(
 class MultipleDataResponse(
     MultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     MultipleDataSuccessDescriptor,
-    SuccessResponse[List[ModelDataT], PaginationT, ModelMetadataT],
+    SuccessResponse[list[ModelDataT], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
-        data: List[ModelDataT],
+        message: OptStr = None,
+        description: OptStr = None,
+        data: list[ModelDataT],
         pagination: PaginationT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -805,16 +838,16 @@ class MultipleDataResponse(
 class CreateMultipleDataResponse(
     CreateMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     CreateMultipleDataSuccessDescriptor,
-    SuccessResponse[DataPair[None, List[ModelDataT]], PaginationT, ModelMetadataT],
+    SuccessResponse[DataPair[None, list[ModelDataT]], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
-        data: List[ModelDataT],
+        message: OptStr = None,
+        description: OptStr = None,
+        data: list[ModelDataT],
         pagination: PaginationT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -825,7 +858,7 @@ class CreateMultipleDataResponse(
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[None, List[ModelDataT]](
+            data=DataPair[None, list[ModelDataT]](
                 old=None,
                 new=data,
             ),
@@ -838,16 +871,16 @@ class CreateMultipleDataResponse(
 class ReadMultipleDataResponse(
     ReadMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     ReadMultipleDataSuccessDescriptor,
-    SuccessResponse[DataPair[List[ModelDataT], None], PaginationT, ModelMetadataT],
+    SuccessResponse[DataPair[list[ModelDataT], None], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
-        data: List[ModelDataT],
+        message: OptStr = None,
+        description: OptStr = None,
+        data: list[ModelDataT],
         pagination: PaginationT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -858,7 +891,7 @@ class ReadMultipleDataResponse(
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[List[ModelDataT], None](
+            data=DataPair[list[ModelDataT], None](
                 old=data,
                 new=None,
             ),
@@ -872,7 +905,7 @@ class UpdateMultipleDataResponse(
     UpdateMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     UpdateMultipleDataSuccessDescriptor,
     SuccessResponse[
-        DataPair[List[ModelDataT], List[ModelDataT]], PaginationT, ModelMetadataT
+        DataPair[list[ModelDataT], list[ModelDataT]], PaginationT, ModelMetadataT
     ],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
@@ -880,10 +913,10 @@ class UpdateMultipleDataResponse(
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
-        old_data: List[ModelDataT],
-        new_data: List[ModelDataT],
+        message: OptStr = None,
+        description: OptStr = None,
+        old_data: list[ModelDataT],
+        new_data: list[ModelDataT],
         pagination: PaginationT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -894,7 +927,7 @@ class UpdateMultipleDataResponse(
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[List[ModelDataT], List[ModelDataT]](
+            data=DataPair[list[ModelDataT], list[ModelDataT]](
                 old=old_data,
                 new=new_data,
             ),
@@ -907,16 +940,16 @@ class UpdateMultipleDataResponse(
 class DeleteMultipleDataResponse(
     DeleteMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     DeleteMultipleDataSuccessDescriptor,
-    SuccessResponse[DataPair[List[ModelDataT], None], PaginationT, ModelMetadataT],
+    SuccessResponse[DataPair[list[ModelDataT], None], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
-        data: List[ModelDataT],
+        message: OptStr = None,
+        description: OptStr = None,
+        data: list[ModelDataT],
         pagination: PaginationT,
         metadata: ModelMetadataT = None,
         other: Any = None,
@@ -927,7 +960,7 @@ class DeleteMultipleDataResponse(
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[List[ModelDataT], None](
+            data=DataPair[list[ModelDataT], None](
                 old=data,
                 new=None,
             ),
@@ -937,24 +970,24 @@ class DeleteMultipleDataResponse(
         )
 
 
-class OptionalMultipleDataResponse(
-    OptionalMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
-    OptionalMultipleDataSuccessDescriptor,
-    SuccessResponse[Optional[List[ModelDataT]], PaginationT, ModelMetadataT],
+class OptMultipleDataResponse(
+    OptMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
+    OptMultipleDataSuccessDescriptor,
+    SuccessResponse[list[ModelDataT] | None, PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
         cls,
         *,
-        message: OptionalString = None,
-        description: OptionalString = None,
-        data: Optional[List[ModelDataT]],
+        message: OptStr = None,
+        description: OptStr = None,
+        data: list[ModelDataT] | None = None,
         pagination: PaginationT,
         metadata: ModelMetadataT = None,
         other: Any = None,
-    ) -> "OptionalMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
-        descriptor = OptionalMultipleDataSuccessDescriptor()
+    ) -> "OptMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
+        descriptor = OptMultipleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
@@ -967,26 +1000,26 @@ class OptionalMultipleDataResponse(
         )
 
 
-AnySuccessResponse = Union[
-    AnyDataResponse[ModelDataT, OptionalPaginationT, ModelMetadataT],
-    NoDataResponse[ModelMetadataT],
-    SingleDataResponse[ModelDataT, ModelMetadataT],
-    CreateSingleDataResponse[ModelDataT, ModelMetadataT],
-    ReadSingleDataResponse[ModelDataT, ModelMetadataT],
-    UpdateSingleDataResponse[ModelDataT, ModelMetadataT],
-    DeleteSingleDataResponse[ModelDataT, ModelMetadataT],
-    OptionalSingleDataResponse[ModelDataT, ModelMetadataT],
-    MultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
-    CreateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
-    ReadMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
-    UpdateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
-    DeleteMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
-    OptionalMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
-]
+AnySuccessResponse = (
+    AnyDataResponse[ModelDataT, OptPaginationT, ModelMetadataT]
+    | NoDataResponse[ModelMetadataT]
+    | SingleDataResponse[ModelDataT, ModelMetadataT]
+    | CreateSingleDataResponse[ModelDataT, ModelMetadataT]
+    | ReadSingleDataResponse[ModelDataT, ModelMetadataT]
+    | UpdateSingleDataResponse[ModelDataT, ModelMetadataT]
+    | DeleteSingleDataResponse[ModelDataT, ModelMetadataT]
+    | OptSingleDataResponse[ModelDataT, ModelMetadataT]
+    | MultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]
+    | CreateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]
+    | ReadMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]
+    | UpdateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]
+    | DeleteMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]
+    | OptMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]
+)
 SuccessResponseT = TypeVar("SuccessResponseT", bound=AnySuccessResponse)
 
 
-AnyResponse = Union[AnyErrorResponse, AnySuccessResponse]
+AnyResponse = AnyErrorResponse | AnySuccessResponse
 ResponseT = TypeVar("ResponseT", bound=AnyResponse)
 
 
