@@ -12,23 +12,36 @@ from typing import (
     Callable,
     Generic,
     Literal,
-    Optional,
     Self,
     TypeGuard,
     TypeVar,
-    Union,
     overload,
 )
-from maleo.types.integer import OptionalInteger
-from maleo.types.string import (
-    ListOfStrings,
-    OptionalListOfStrings,
-    OptionalSequenceOfStrings,
+from maleo.enums.organization import ListOfOrganizationRoles
+from maleo.enums.medical import (
+    OptSeqOfMedicalRoles,
+    OptListOfMedicalRoles,
+    OptListOfMedicalRolesT,
 )
-from maleo.types.uuid import OptionalUUID
+from maleo.enums.system import ListOfSystemRoles
+from maleo.types.integer import OptInt
+from maleo.types.string import (
+    OptStr,
+    OptStrT,
+    ListOfStrs,
+    OptListOfStrs,
+    OptSeqOfStrs,
+)
+from maleo.types.uuid import OptUUID
 from maleo.utils.exception import extract_details
-from ..mixins.identity import EntityIdentifier, OptionalEntityIdentifier
-from .enums import Domain, OptionalDomain, OptionalDomainT
+from ..mixins.identity import EntityIdentifier, OptEntityIdentifier
+from .enums import Domain, OptDomain, OptDomainT
+from .types import (
+    ListOfDomainRoles,
+    OptListOfDomainRoles,
+    OptListOfDomainRolesT,
+    OptSeqOfDomainRoles,
+)
 
 
 class ConversionDestination(StrEnum):
@@ -38,22 +51,22 @@ class ConversionDestination(StrEnum):
     SYSTEM = "system"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
 class RequestCredentials(StarletteCredentials):
     def __init__(
         self,
-        domain: OptionalDomain = None,
-        user_id: OptionalInteger = None,
-        user_uuid: OptionalUUID = None,
-        organization_id: OptionalInteger = None,
-        organization_uuid: OptionalUUID = None,
-        roles: OptionalSequenceOfStrings = None,
-        scopes: OptionalSequenceOfStrings = None,
+        domain: OptDomain = None,
+        user_id: OptInt = None,
+        user_uuid: OptUUID = None,
+        organization_id: OptInt = None,
+        organization_uuid: OptUUID = None,
+        domain_roles: OptSeqOfDomainRoles = None,
+        medical_roles: OptSeqOfMedicalRoles = None,
+        scopes: OptSeqOfStrs = None,
     ):
-        super().__init__(scopes)
         self.domain = domain
 
         if user_id is None and user_uuid is None:
@@ -76,17 +89,23 @@ class RequestCredentials(StarletteCredentials):
                 "Both 'organization_id' and 'organization_uuid' must either be None or not None"
             )
 
-        self.roles = [] if roles is None else list(roles)
+        self.domain_roles: OptListOfDomainRoles = list(domain_roles) if domain_roles is not None else None  # type: ignore
+        self.medical_roles: OptListOfMedicalRoles = (
+            list(medical_roles) if medical_roles is not None else None
+        )
+        self.scopes: OptListOfStrs = list[str](scopes) if scopes is not None else None
 
 
 class RequestUser(StarletteUser):
     def __init__(
         self,
         authenticated: bool = False,
+        organization: OptStr = None,
         username: str = "",
         email: str = "",
     ) -> None:
         self._authenticated = authenticated
+        self._organization = organization
         self._username = username
         self._email = email
 
@@ -94,6 +113,10 @@ class RequestUser(StarletteUser):
     def is_authenticated(self) -> bool:
         return self._authenticated
 
+    @property
+    def organization(self) -> OptStr:
+        return self._organization
+
     @property
     def display_name(self) -> str:
         return self._username
@@ -103,63 +126,76 @@ class RequestUser(StarletteUser):
         return self._email
 
 
-UserT = TypeVar("UserT", bound=OptionalEntityIdentifier)
-OrganizationT = TypeVar("OrganizationT", bound=OptionalEntityIdentifier)
-RolesT = TypeVar("RolesT", bound=OptionalListOfStrings)
-ScopesT = TypeVar("ScopesT", bound=OptionalListOfStrings)
+UserT = TypeVar("UserT", bound=OptEntityIdentifier)
+OrganizationT = TypeVar("OrganizationT", bound=OptEntityIdentifier)
+ScopesT = TypeVar("ScopesT", bound=OptListOfStrs)
 
 
 class GenericCredentials(
     BaseModel,
     Generic[
-        OptionalDomainT,
+        OptDomainT,
         UserT,
         OrganizationT,
-        RolesT,
+        OptListOfDomainRolesT,
+        OptListOfMedicalRolesT,
         ScopesT,
     ],
 ):
-    domain: OptionalDomainT = Field(..., description="Domain")
-    user: UserT = Field(..., description="User")
-    organization: OrganizationT = Field(..., description="Organization")
-    roles: RolesT = Field(..., description="Roles")
-    scopes: ScopesT = Field(..., description="Scopes")
+    domain: Annotated[OptDomainT, Field(..., description="Domain")]
+    user: Annotated[UserT, Field(..., description="User")]
+    organization: Annotated[OrganizationT, Field(..., description="Organization")]
+    domain_roles: Annotated[
+        OptListOfDomainRolesT, Field(..., description="Domain Roles")
+    ]
+    medical_roles: Annotated[
+        OptListOfMedicalRolesT, Field(..., description="Medical roles")
+    ]
+    scopes: Annotated[ScopesT, Field(..., description="Scopes")]
 
 
 class BaseCredentials(
     GenericCredentials[
-        OptionalDomain,
-        OptionalEntityIdentifier,
-        OptionalEntityIdentifier,
-        OptionalListOfStrings,
-        OptionalListOfStrings,
+        OptDomain,
+        OptEntityIdentifier,
+        OptEntityIdentifier,
+        OptListOfDomainRoles,
+        OptListOfMedicalRoles,
+        OptListOfStrs,
     ]
 ):
-    domain: Annotated[OptionalDomain, Field(None, description="Domain")] = None
-    user: Annotated[OptionalEntityIdentifier, Field(None, description="User")] = None
+    domain: Annotated[OptDomain, Field(None, description="Domain")] = None
+    user: Annotated[OptEntityIdentifier, Field(None, description="User")] = None
     organization: Annotated[
-        OptionalEntityIdentifier, Field(None, description="Organization")
+        OptEntityIdentifier, Field(None, description="Organization")
     ] = None
-    roles: Annotated[OptionalListOfStrings, Field(None, description="Roles")] = None
-    scopes: Annotated[OptionalListOfStrings, Field(None, description="Scopes")] = None
+    domain_roles: Annotated[
+        OptListOfDomainRoles, Field(None, description="Domain Roles")
+    ] = None
+    medical_roles: Annotated[
+        OptListOfMedicalRoles, Field(None, description="Medical roles")
+    ] = None
+    scopes: Annotated[OptListOfStrs, Field(None, description="Scopes")] = None
 
 
 class AuthenticatedCredentials(
     GenericCredentials[
         Domain,
         EntityIdentifier,
-        OptionalEntityIdentifier,
-        ListOfStrings,
-        ListOfStrings,
+        OptEntityIdentifier,
+        ListOfDomainRoles,
+        OptListOfMedicalRoles,
+        ListOfStrs,
     ]
 ):
     domain: Annotated[Domain, Field(..., description="Domain")]
     user: Annotated[EntityIdentifier, Field(..., description="User")]
-    organization: Annotated[
-        OptionalEntityIdentifier, Field(..., description="Organization")
+    organization: Annotated[OptEntityIdentifier, Field(..., description="Organization")]
+    domain_roles: Annotated[ListOfDomainRoles, Field(..., description="Domain Roles")]
+    medical_roles: Annotated[
+        OptListOfMedicalRoles, Field(..., description="Medical roles")
     ]
-    roles: Annotated[ListOfStrings, Field(..., description="Roles")]
-    scopes: Annotated[ListOfStrings, Field(..., description="Scopes")]
+    scopes: Annotated[ListOfStrs, Field(..., description="Scopes")]
 
 
 class TenantCredentials(
@@ -167,15 +203,21 @@ class TenantCredentials(
         Literal[Domain.TENANT],
         EntityIdentifier,
         EntityIdentifier,
-        ListOfStrings,
-        ListOfStrings,
+        ListOfOrganizationRoles,
+        OptListOfMedicalRoles,
+        ListOfStrs,
     ]
 ):
     domain: Literal[Domain.TENANT] = Domain.TENANT
     user: Annotated[EntityIdentifier, Field(..., description="User")]
     organization: Annotated[EntityIdentifier, Field(..., description="Organization")]
-    roles: Annotated[ListOfStrings, Field(..., description="Roles")]
-    scopes: Annotated[ListOfStrings, Field(..., description="Scopes")]
+    domain_roles: Annotated[
+        ListOfOrganizationRoles, Field(..., description="Domain Roles")
+    ]
+    medical_roles: Annotated[
+        OptListOfMedicalRoles, Field(..., description="Medical roles")
+    ]
+    scopes: Annotated[ListOfStrs, Field(..., description="Scopes")]
 
 
 class SystemCredentials(
@@ -183,20 +225,22 @@ class SystemCredentials(
         Literal[Domain.SYSTEM],
         EntityIdentifier,
         None,
-        ListOfStrings,
-        ListOfStrings,
+        ListOfSystemRoles,
+        None,
+        ListOfStrs,
     ]
 ):
     domain: Literal[Domain.SYSTEM] = Domain.SYSTEM
     user: Annotated[EntityIdentifier, Field(..., description="User")]
     organization: Annotated[None, Field(None, description="Organization")] = None
-    roles: Annotated[ListOfStrings, Field(..., description="Roles")]
-    scopes: Annotated[ListOfStrings, Field(..., description="Scopes")]
+    domain_roles: Annotated[ListOfSystemRoles, Field(..., description="Domain Roles")]
+    medical_roles: Annotated[None, Field(None, description="Medical roles")] = None
+    scopes: Annotated[ListOfStrs, Field(..., description="Scopes")]
 
 
-AnyCredentials = Union[
-    BaseCredentials, AuthenticatedCredentials, TenantCredentials, SystemCredentials
-]
+AnyCredentials = (
+    BaseCredentials | AuthenticatedCredentials | TenantCredentials | SystemCredentials
+)
 AnyCredentialsT = TypeVar("AnyCredentialsT", bound=AnyCredentials)
 
 
@@ -207,21 +251,32 @@ class CredentialsMixin(BaseModel, Generic[AnyCredentialsT]):
 IsAuthenticatedT = TypeVar("IsAuthenticatedT", bound=bool)
 
 
-class GenericUser(BaseModel, Generic[IsAuthenticatedT]):
+class GenericUser(BaseModel, Generic[IsAuthenticatedT, OptStrT]):
     is_authenticated: IsAuthenticatedT = Field(..., description="Authenticated")
+    organization: Annotated[OptStrT, Field(..., description="Organization")]
     display_name: Annotated[str, Field("", description="Username")] = ""
     identity: Annotated[str, Field("", description="Email")] = ""
 
 
-class BaseUser(GenericUser[bool]):
+class BaseUser(GenericUser[bool, OptStr]):
     is_authenticated: Annotated[bool, Field(False, description="Authenticated")] = False
+    organization: Annotated[OptStr, Field(None, description="Organization")] = None
 
 
-class AuthenticatedUser(GenericUser[Literal[True]]):
+class AuthenticatedUser(GenericUser[Literal[True], OptStr]):
     is_authenticated: Literal[True] = True
+    organization: Annotated[OptStr, Field(..., description="Organization")]
 
 
-AnyUser = Union[BaseUser, AuthenticatedUser]
+class TenantUser(GenericUser[Literal[True], str]):
+    organization: Annotated[str, Field(..., description="Organization")]
+
+
+class SystemUser(GenericUser[Literal[True], None]):
+    organization: Annotated[None, Field(None, description="Organization")] = None
+
+
+AnyUser = BaseUser | AuthenticatedUser | TenantUser | SystemUser
 AnyUserT = TypeVar("AnyUserT", bound=AnyUser)
 
 
@@ -286,12 +341,10 @@ class GenericAuthentication(
 class BaseAuthentication(GenericAuthentication[BaseCredentials, BaseUser]):
     credentials: Annotated[
         BaseCredentials,
-        Field(default_factory=BaseCredentials, description="Credentials"),
+        Field(BaseCredentials(), description="Credentials"),
     ] = BaseCredentials()
 
-    user: Annotated[BaseUser, Field(default_factory=BaseUser, description="User")] = (
-        BaseUser()
-    )
+    user: Annotated[BaseUser, Field(BaseUser(), description="User")] = BaseUser()
 
     @classmethod
     def _extract(
@@ -316,9 +369,7 @@ class AuthenticatedAuthentication(
         AuthenticatedCredentials, Field(..., description="Credentials")
     ]
 
-    user: Annotated[
-        AuthenticatedUser, Field(default_factory=AuthenticatedUser, description="User")
-    ] = AuthenticatedUser()
+    user: Annotated[AuthenticatedUser, Field(..., description="User")]
 
     @classmethod
     def _extract(
@@ -338,12 +389,9 @@ class AuthenticatedAuthentication(
         return cls(credentials=credentials, user=user)
 
 
-class TenantAuthentication(GenericAuthentication[TenantCredentials, AuthenticatedUser]):
+class TenantAuthentication(GenericAuthentication[TenantCredentials, TenantUser]):
     credentials: Annotated[TenantCredentials, Field(..., description="Credentials")]
-
-    user: Annotated[
-        AuthenticatedUser, Field(default_factory=AuthenticatedUser, description="User")
-    ] = AuthenticatedUser()
+    user: Annotated[TenantUser, Field(..., description="User")]
 
     @classmethod
     def _extract(
@@ -357,16 +405,13 @@ class TenantAuthentication(GenericAuthentication[TenantCredentials, Authenticate
 
         # validate user
         cls._validate_request_user(conn=conn)
-        user = AuthenticatedUser.model_validate(conn.user, from_attributes=True)
+        user = TenantUser.model_validate(conn.user, from_attributes=True)
         return cls(credentials=credentials, user=user)
 
 
-class SystemAuthentication(GenericAuthentication[SystemCredentials, AuthenticatedUser]):
+class SystemAuthentication(GenericAuthentication[SystemCredentials, SystemUser]):
     credentials: Annotated[SystemCredentials, Field(..., description="Credentials")]
-
-    user: Annotated[
-        AuthenticatedUser, Field(default_factory=AuthenticatedUser, description="User")
-    ] = AuthenticatedUser()
+    user: Annotated[SystemUser, Field(..., description="User")]
 
     @classmethod
     def _extract(
@@ -380,29 +425,27 @@ class SystemAuthentication(GenericAuthentication[SystemCredentials, Authenticate
 
         # validate user
         cls._validate_request_user(conn=conn)
-        user = AuthenticatedUser.model_validate(conn.user, from_attributes=True)
+        user = SystemUser.model_validate(conn.user, from_attributes=True)
         return cls(credentials=credentials, user=user)
 
 
-AnyAuthenticatedAuthentication = Union[
-    AuthenticatedAuthentication, TenantAuthentication, SystemAuthentication
-]
+AnyAuthenticatedAuthentication = (
+    AuthenticatedAuthentication | TenantAuthentication | SystemAuthentication
+)
 AnyAuthenticatedAuthenticationT = TypeVar(
     "AnyAuthenticatedAuthenticationT", bound=AnyAuthenticatedAuthentication
 )
-OptionalAnyAuthenticatedAuthentication = Optional[AnyAuthenticatedAuthentication]
-OptionalAnyAuthenticatedAuthenticationT = TypeVar(
-    "OptionalAnyAuthenticatedAuthenticationT",
-    bound=OptionalAnyAuthenticatedAuthentication,
+OptAnyAuthenticatedAuthentication = AnyAuthenticatedAuthentication | None
+OptAnyAuthenticatedAuthenticationT = TypeVar(
+    "OptAnyAuthenticatedAuthenticationT",
+    bound=OptAnyAuthenticatedAuthentication,
 )
 
 
-AnyAuthentication = Union[BaseAuthentication, AnyAuthenticatedAuthentication]
+AnyAuthentication = BaseAuthentication | AnyAuthenticatedAuthentication
 AnyAuthenticationT = TypeVar("AnyAuthenticationT", bound=AnyAuthentication)
-OptionalAnyAuthentication = Optional[AnyAuthentication]
-OptionalAnyAuthenticationT = TypeVar(
-    "OptionalAnyAuthenticationT", bound=OptionalAnyAuthentication
-)
+OptAnyAuthentication = AnyAuthentication | None
+OptAnyAuthenticationT = TypeVar("OptAnyAuthenticationT", bound=OptAnyAuthentication)
 
 
 def is_authenticated(
@@ -412,7 +455,7 @@ def is_authenticated(
         authentication.user.is_authenticated
         and authentication.credentials.domain is not None
         and authentication.credentials.user is not None
-        and authentication.credentials.roles is not None
+        and authentication.credentials.domain_roles is not None
         and authentication.credentials.scopes is not None
     )
 
@@ -422,10 +465,11 @@ def is_tenant(
 ) -> TypeGuard[TenantAuthentication]:
     return (
         authentication.user.is_authenticated
+        and authentication.user.organization is not None
         and authentication.credentials.domain is Domain.TENANT
         and authentication.credentials.user is not None
         and authentication.credentials.organization is not None
-        and authentication.credentials.roles is not None
+        and authentication.credentials.domain_roles is not None
         and authentication.credentials.scopes is not None
     )
 
@@ -435,18 +479,18 @@ def is_system(
 ) -> TypeGuard[SystemAuthentication]:
     return (
         authentication.user.is_authenticated
+        and authentication.user.organization is None
         and authentication.credentials.domain is Domain.SYSTEM
         and authentication.credentials.user is not None
         and authentication.credentials.organization is None
-        and authentication.credentials.roles is not None
+        and authentication.credentials.domain_roles is not None
+        and authentication.credentials.medical_roles is None
         and authentication.credentials.scopes is not None
     )
 
 
-class AuthenticationMixin(BaseModel, Generic[OptionalAnyAuthenticationT]):
-    authentication: OptionalAnyAuthenticationT = Field(
-        ..., description="Authentication"
-    )
+class AuthenticationMixin(BaseModel, Generic[OptAnyAuthenticationT]):
+    authentication: OptAnyAuthenticationT = Field(..., description="Authentication")
 
 
 class Factory:
@@ -486,7 +530,7 @@ class Factory:
     @classmethod
     def extract(
         cls,
-        domain: OptionalDomain = None,
+        domain: OptDomain = None,
         *,
         conn: HTTPConnection,
         mandatory: bool = False,
@@ -494,7 +538,7 @@ class Factory:
     @classmethod
     def extract(
         cls,
-        domain: OptionalDomain = None,
+        domain: OptDomain = None,
         *,
         conn: HTTPConnection,
         mandatory: bool = True,
@@ -530,7 +574,7 @@ class Factory:
     ) -> Callable[[HTTPConnection], BaseAuthentication]: ...
     @classmethod
     def as_dependency(
-        cls, domain: OptionalDomain = None, *, mandatory: bool = True
+        cls, domain: OptDomain = None, *, mandatory: bool = True
     ) -> Callable[[HTTPConnection], AnyAuthentication]:
 
         def dependency(conn: HTTPConnection) -> AnyAuthentication:
