@@ -15,17 +15,15 @@ from typing import (
     Generator,
     Generic,
     Literal,
-    Optional,
     Self,
     TypeGuard,
     TypeVar,
-    Union,
     overload,
 )
-from maleo.enums.connection import Header, Protocol
-from maleo.types.misc import BytesOrString
-from maleo.types.string import ListOfStrings, OptionalString
-from .enums import Domain
+from maleo.enums.connection import Header, Protocol, OptProtocol
+from maleo.types.misc import BytesOrStr
+from maleo.types.string import ListOfStrs, OptStr
+from .enums import Domain, OptDomain
 from .token import TenantToken, SystemToken, AnyToken, Factory as TokenFactory
 
 
@@ -34,17 +32,25 @@ class Scheme(StrEnum):
     BEARER_TOKEN = "bearer_token"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
 SchemeT = TypeVar("SchemeT", bound=Scheme)
+OptScheme = Scheme | None
 
 
 class Source(StrEnum):
     HEADER = "header"
     STATE = "state"
 
+    @classmethod
+    def choices(cls) -> ListOfStrs:
+        return [e.value for e in cls]
+
+
+OptSource = Source | None
+
 
 class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
     scheme: SchemeT = Field(..., description="Authorization's scheme")
@@ -54,7 +60,7 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
     @classmethod
     def from_state(
         cls, conn: HTTPConnection, *, auto_error: Literal[False]
-    ) -> Optional[Self]: ...
+    ) -> Self | None: ...
     @overload
     @classmethod
     def from_state(
@@ -63,7 +69,7 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
     @classmethod
     def from_state(
         cls, conn: HTTPConnection, *, auto_error: bool = True
-    ) -> Optional[Self]:
+    ) -> Self | None:
         authorization = getattr(conn.state, "authorization", None)
         if isinstance(authorization, cls):
             return authorization
@@ -80,23 +86,21 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
     @abstractmethod
     def from_header(
         cls, conn: HTTPConnection, *, auto_error: bool = True
-    ) -> Optional[Self]:
+    ) -> Self | None:
         """Extract authorization from Header"""
 
     @overload
     @classmethod
     def extract(
         cls, conn: HTTPConnection, *, auto_error: Literal[False]
-    ) -> Optional[Self]: ...
+    ) -> Self | None: ...
     @overload
     @classmethod
     def extract(
         cls, conn: HTTPConnection, *, auto_error: Literal[True] = True
     ) -> Self: ...
     @classmethod
-    def extract(
-        cls, conn: HTTPConnection, *, auto_error: bool = True
-    ) -> Optional[Self]:
+    def extract(cls, conn: HTTPConnection, *, auto_error: bool = True) -> Self | None:
         authorization = cls.from_state(conn, auto_error=auto_error)
         if isinstance(authorization, cls):
             return authorization
@@ -121,8 +125,8 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
         *,
         auto_error: Literal[False],
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[Self],
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
+        Self | None,
     ]: ...
     @overload
     @classmethod
@@ -132,7 +136,7 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
         *,
         auto_error: Literal[True] = True,
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString], Self
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr], Self
     ]: ...
     @overload
     @classmethod
@@ -142,8 +146,8 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
         *,
         auto_error: Literal[False],
     ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[Self],
+        [Request, HTTPAuthorizationCredentials | None, OptStr],
+        Self | None,
     ]: ...
     @overload
     @classmethod
@@ -152,14 +156,12 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
         protocol: Literal[Protocol.HTTP],
         *,
         auto_error: Literal[True] = True,
-    ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString], Self
-    ]: ...
+    ) -> Callable[[Request, HTTPAuthorizationCredentials | None, OptStr], Self]: ...
     @overload
     @classmethod
     def as_dependency(
         cls, protocol: Literal[Protocol.WEBSOCKET], *, auto_error: Literal[False]
-    ) -> Callable[[WebSocket], Optional[Self]]: ...
+    ) -> Callable[[WebSocket], Self | None]: ...
     @overload
     @classmethod
     def as_dependency(
@@ -167,56 +169,56 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
     ) -> Callable[[WebSocket], Self]: ...
     @classmethod
     def as_dependency(
-        cls, protocol: Optional[Protocol] = None, *, auto_error: bool = True
-    ) -> Union[
+        cls, protocol: OptProtocol = None, *, auto_error: bool = True
+    ) -> (
         Callable[
-            [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
-            Optional[Self],
-        ],
-        Callable[
-            [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
+            [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
+            Self | None,
+        ]
+        | Callable[
+            [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
             Self,
-        ],
-        Callable[
-            [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
-            Optional[Self],
-        ],
-        Callable[
-            [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
+        ]
+        | Callable[
+            [Request, HTTPAuthorizationCredentials | None, OptStr],
+            Self | None,
+        ]
+        | Callable[
+            [Request, HTTPAuthorizationCredentials | None, OptStr],
             Self,
-        ],
-        Callable[[WebSocket], Optional[Self]],
-        Callable[[WebSocket], Self],
-    ]:
+        ]
+        | Callable[[WebSocket], Self | None]
+        | Callable[[WebSocket], Self]
+    ):
         def _dependency(
             conn: HTTPConnection,
             # These are for documentation purpose only
             bearer: Annotated[
-                Optional[HTTPAuthorizationCredentials],
+                HTTPAuthorizationCredentials | None,
                 Security(HTTPBearer(auto_error=False)),
             ],
             api_key: Annotated[
-                OptionalString,
+                OptStr,
                 Security(APIKeyHeader(name=Header.X_API_KEY.value, auto_error=False)),
             ],
-        ) -> Optional[Self]:
+        ) -> Self | None:
             return cls.extract(conn, auto_error=auto_error)
 
         def _request_dependency(
             request: Request,
             # These are for documentation purpose only
             bearer: Annotated[
-                Optional[HTTPAuthorizationCredentials],
+                HTTPAuthorizationCredentials | None,
                 Security(HTTPBearer(auto_error=False)),
             ],
             api_key: Annotated[
-                OptionalString,
+                OptStr,
                 Security(APIKeyHeader(name=Header.X_API_KEY.value, auto_error=False)),
             ],
-        ) -> Optional[Self]:
+        ) -> Self | None:
             return cls.extract(request, auto_error=auto_error)
 
-        def _websocket_dependency(websocket: WebSocket) -> Optional[Self]:
+        def _websocket_dependency(websocket: WebSocket) -> Self | None:
             return cls.extract(websocket, auto_error=auto_error)
 
         if protocol is None:
@@ -231,9 +233,9 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
         self,
         domain: Literal[Domain.TENANT],
         *,
-        key: Union[RsaKey, BytesOrString],
+        key: BytesOrStr | RsaKey,
         audience: str | Iterable[str] | None = None,
-        subject: OptionalString = None,
+        subject: OptStr = None,
         issuer: str | Sequence[str] | None = None,
         leeway: float | timedelta = 0,
     ) -> TenantToken: ...
@@ -242,9 +244,9 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
         self,
         domain: Literal[Domain.SYSTEM],
         *,
-        key: Union[RsaKey, BytesOrString],
+        key: BytesOrStr | RsaKey,
         audience: str | Iterable[str] | None = None,
-        subject: OptionalString = None,
+        subject: OptStr = None,
         issuer: str | Sequence[str] | None = None,
         leeway: float | timedelta = 0,
     ) -> SystemToken: ...
@@ -253,19 +255,19 @@ class GenericAuthorization(ABC, BaseModel, Generic[SchemeT]):
         self,
         domain: None = None,
         *,
-        key: Union[RsaKey, BytesOrString],
+        key: BytesOrStr | RsaKey,
         audience: str | Iterable[str] | None = None,
-        subject: OptionalString = None,
+        subject: OptStr = None,
         issuer: str | Sequence[str] | None = None,
         leeway: float | timedelta = 0,
     ) -> AnyToken: ...
     def parse_token(
         self,
-        domain: Optional[Domain] = None,
+        domain: OptDomain = None,
         *,
-        key: Union[RsaKey, BytesOrString],
+        key: BytesOrStr | RsaKey,
         audience: str | Iterable[str] | None = None,
-        subject: OptionalString = None,
+        subject: OptStr = None,
         issuer: str | Sequence[str] | None = None,
         leeway: float | timedelta = 0,
     ) -> AnyToken:
@@ -291,7 +293,7 @@ class BaseAuthorization(GenericAuthorization[Scheme]):
     @classmethod
     def from_header(
         cls, conn: HTTPConnection, *, auto_error: Literal[False]
-    ) -> Optional[Self]: ...
+    ) -> Self | None: ...
     @overload
     @classmethod
     def from_header(
@@ -300,7 +302,7 @@ class BaseAuthorization(GenericAuthorization[Scheme]):
     @classmethod
     def from_header(
         cls, conn: HTTPConnection, *, auto_error: bool = True
-    ) -> Optional[Self]:
+    ) -> Self | None:
         token = conn.headers.get(Header.AUTHORIZATION.value, "")
         scheme, _, credentials = token.partition(" ")
         if token and scheme and credentials and scheme.lower() == "bearer":
@@ -329,7 +331,7 @@ class APIKeyAuthorization(GenericAuthorization[Literal[Scheme.API_KEY]]):
     @classmethod
     def from_header(
         cls, conn: HTTPConnection, *, auto_error: Literal[False]
-    ) -> Optional[Self]: ...
+    ) -> Self | None: ...
     @overload
     @classmethod
     def from_header(
@@ -338,7 +340,7 @@ class APIKeyAuthorization(GenericAuthorization[Literal[Scheme.API_KEY]]):
     @classmethod
     def from_header(
         cls, conn: HTTPConnection, *, auto_error: bool = True
-    ) -> Optional[Self]:
+    ) -> Self | None:
         api_key = conn.headers.get(Header.X_API_KEY)
         if api_key is not None:
             return cls(scheme=Scheme.API_KEY, credentials=api_key)
@@ -362,7 +364,7 @@ class BearerTokenAuthorization(GenericAuthorization[Literal[Scheme.BEARER_TOKEN]
     @classmethod
     def from_header(
         cls, conn: HTTPConnection, *, auto_error: Literal[False]
-    ) -> Optional[Self]: ...
+    ) -> Self | None: ...
     @overload
     @classmethod
     def from_header(
@@ -371,7 +373,7 @@ class BearerTokenAuthorization(GenericAuthorization[Literal[Scheme.BEARER_TOKEN]
     @classmethod
     def from_header(
         cls, conn: HTTPConnection, *, auto_error: bool = True
-    ) -> Optional[Self]:
+    ) -> Self | None:
         token = conn.headers.get(Header.AUTHORIZATION.value, "")
         scheme, _, credentials = token.partition(" ")
         if token and scheme and credentials and scheme.lower() == "bearer":
@@ -386,14 +388,10 @@ class BearerTokenAuthorization(GenericAuthorization[Literal[Scheme.BEARER_TOKEN]
         return None
 
 
-AnyAuthorization = Union[
-    BaseAuthorization, BearerTokenAuthorization, APIKeyAuthorization
-]
+AnyAuthorization = BaseAuthorization | BearerTokenAuthorization | APIKeyAuthorization
 AnyAuthorizationT = TypeVar("AnyAuthorizationT", bound=AnyAuthorization)
-OptionalAnyAuthorization = Optional[AnyAuthorization]
-OptionalAnyAuthorizationT = TypeVar(
-    "OptionalAnyAuthorizationT", bound=OptionalAnyAuthorization
-)
+OptAnyAuthorization = AnyAuthorization | None
+OptAnyAuthorizationT = TypeVar("OptAnyAuthorizationT", bound=OptAnyAuthorization)
 
 
 def is_bearer_token(
@@ -406,8 +404,8 @@ def is_api_key(authorization: AnyAuthorization) -> TypeGuard[APIKeyAuthorization
     return authorization.scheme is Scheme.API_KEY
 
 
-class AuthorizationMixin(BaseModel, Generic[OptionalAnyAuthorizationT]):
-    authorization: OptionalAnyAuthorizationT = Field(
+class AuthorizationMixin(BaseModel, Generic[OptAnyAuthorizationT]):
+    authorization: OptAnyAuthorizationT = Field(
         ...,
         description="Authorization",
     )
@@ -441,7 +439,7 @@ class BearerTokenAuth(httpx.Auth):
         return f"Bearer {token}"
 
 
-AnyHTTPXAuthorization = Union[APIKeyAuth, BearerTokenAuth]
+AnyHTTPXAuthorization = APIKeyAuth | BearerTokenAuth
 
 
 class Factory:
@@ -450,37 +448,37 @@ class Factory:
     def extract(
         cls,
         scheme: None = None,
-        source: Optional[Source] = None,
+        source: OptSource = None,
         *,
         conn: HTTPConnection,
         auto_error: Literal[False],
-    ) -> Optional[BaseAuthorization]: ...
+    ) -> BaseAuthorization | None: ...
     @overload
     @classmethod
     def extract(
         cls,
         scheme: Literal[Scheme.API_KEY],
-        source: Optional[Source] = None,
+        source: OptSource = None,
         *,
         conn: HTTPConnection,
         auto_error: Literal[False],
-    ) -> Optional[APIKeyAuthorization]: ...
+    ) -> APIKeyAuthorization | None: ...
     @overload
     @classmethod
     def extract(
         cls,
         scheme: Literal[Scheme.BEARER_TOKEN],
-        source: Optional[Source] = None,
+        source: OptSource = None,
         *,
         conn: HTTPConnection,
         auto_error: Literal[False],
-    ) -> Optional[BearerTokenAuthorization]: ...
+    ) -> BearerTokenAuthorization | None: ...
     @overload
     @classmethod
     def extract(
         cls,
         scheme: None = None,
-        source: Optional[Source] = None,
+        source: OptSource = None,
         *,
         conn: HTTPConnection,
         auto_error: Literal[True] = True,
@@ -490,7 +488,7 @@ class Factory:
     def extract(
         cls,
         scheme: Literal[Scheme.API_KEY],
-        source: Optional[Source] = None,
+        source: OptSource = None,
         *,
         conn: HTTPConnection,
         auto_error: Literal[True] = True,
@@ -500,7 +498,7 @@ class Factory:
     def extract(
         cls,
         scheme: Literal[Scheme.BEARER_TOKEN],
-        source: Optional[Source] = None,
+        source: OptSource = None,
         *,
         conn: HTTPConnection,
         auto_error: Literal[True] = True,
@@ -508,12 +506,12 @@ class Factory:
     @classmethod
     def extract(
         cls,
-        scheme: Optional[Scheme] = None,
-        source: Optional[Source] = None,
+        scheme: OptScheme = None,
+        source: OptSource = None,
         *,
         conn: HTTPConnection,
         auto_error: bool = True,
-    ) -> OptionalAnyAuthorization:
+    ) -> OptAnyAuthorization:
         if scheme is None:
             if source is None:
                 return BaseAuthorization.extract(conn, auto_error=auto_error)
@@ -545,8 +543,8 @@ class Factory:
         scheme: None = None,
         auto_error: Literal[False],
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[BaseAuthorization],
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
+        BaseAuthorization | None,
     ]: ...
     @overload
     @classmethod
@@ -557,8 +555,8 @@ class Factory:
         scheme: Literal[Scheme.API_KEY],
         auto_error: Literal[False],
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[APIKeyAuthorization],
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
+        APIKeyAuthorization | None,
     ]: ...
     @overload
     @classmethod
@@ -569,8 +567,8 @@ class Factory:
         scheme: Literal[Scheme.BEARER_TOKEN],
         auto_error: Literal[False],
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[BearerTokenAuthorization],
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
+        BearerTokenAuthorization | None,
     ]: ...
     @overload
     @classmethod
@@ -581,7 +579,7 @@ class Factory:
         scheme: None = None,
         auto_error: Literal[True] = True,
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
         BaseAuthorization,
     ]: ...
     @overload
@@ -593,7 +591,7 @@ class Factory:
         scheme: Literal[Scheme.API_KEY],
         auto_error: Literal[True] = True,
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
         APIKeyAuthorization,
     ]: ...
     @overload
@@ -605,7 +603,7 @@ class Factory:
         scheme: Literal[Scheme.BEARER_TOKEN],
         auto_error: Literal[True] = True,
     ) -> Callable[
-        [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
+        [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
         BearerTokenAuthorization,
     ]: ...
 
@@ -618,8 +616,8 @@ class Factory:
         scheme: None = None,
         auto_error: Literal[False],
     ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[BaseAuthorization],
+        [Request, HTTPAuthorizationCredentials | None, OptStr],
+        BaseAuthorization | None,
     ]: ...
     @overload
     @classmethod
@@ -630,8 +628,8 @@ class Factory:
         scheme: Literal[Scheme.API_KEY],
         auto_error: Literal[False],
     ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[APIKeyAuthorization],
+        [Request, HTTPAuthorizationCredentials | None, OptStr],
+        APIKeyAuthorization | None,
     ]: ...
     @overload
     @classmethod
@@ -642,8 +640,8 @@ class Factory:
         scheme: Literal[Scheme.BEARER_TOKEN],
         auto_error: Literal[False],
     ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
-        Optional[BearerTokenAuthorization],
+        [Request, HTTPAuthorizationCredentials | None, OptStr],
+        BearerTokenAuthorization | None,
     ]: ...
     @overload
     @classmethod
@@ -654,7 +652,7 @@ class Factory:
         scheme: None = None,
         auto_error: Literal[True] = True,
     ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
+        [Request, HTTPAuthorizationCredentials | None, OptStr],
         BaseAuthorization,
     ]: ...
     @overload
@@ -666,7 +664,7 @@ class Factory:
         scheme: Literal[Scheme.API_KEY],
         auto_error: Literal[True] = True,
     ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
+        [Request, HTTPAuthorizationCredentials | None, OptStr],
         APIKeyAuthorization,
     ]: ...
     @overload
@@ -678,7 +676,7 @@ class Factory:
         scheme: Literal[Scheme.BEARER_TOKEN],
         auto_error: Literal[True] = True,
     ) -> Callable[
-        [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
+        [Request, HTTPAuthorizationCredentials | None, OptStr],
         BearerTokenAuthorization,
     ]: ...
 
@@ -690,7 +688,7 @@ class Factory:
         *,
         scheme: None = None,
         auto_error: Literal[False],
-    ) -> Callable[[WebSocket], Optional[BaseAuthorization]]: ...
+    ) -> Callable[[WebSocket], BaseAuthorization | None]: ...
     @overload
     @classmethod
     def as_dependency(
@@ -699,7 +697,7 @@ class Factory:
         *,
         scheme: Literal[Scheme.API_KEY],
         auto_error: Literal[False],
-    ) -> Callable[[WebSocket], Optional[APIKeyAuthorization]]: ...
+    ) -> Callable[[WebSocket], APIKeyAuthorization | None]: ...
     @overload
     @classmethod
     def as_dependency(
@@ -708,7 +706,7 @@ class Factory:
         *,
         scheme: Literal[Scheme.BEARER_TOKEN],
         auto_error: Literal[False],
-    ) -> Callable[[WebSocket], Optional[BearerTokenAuthorization]]: ...
+    ) -> Callable[[WebSocket], BearerTokenAuthorization | None]: ...
     @overload
     @classmethod
     def as_dependency(
@@ -740,30 +738,30 @@ class Factory:
     @classmethod
     def as_dependency(
         cls,
-        protocol: Optional[Protocol] = None,
+        protocol: OptProtocol = None,
         *,
-        scheme: Optional[Scheme] = None,
+        scheme: OptScheme = None,
         auto_error: bool = True,
-    ) -> Union[
+    ) -> (
         Callable[
-            [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
-            OptionalAnyAuthorization,
-        ],
-        Callable[
-            [HTTPConnection, Optional[HTTPAuthorizationCredentials], OptionalString],
+            [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
+            OptAnyAuthorization,
+        ]
+        | Callable[
+            [HTTPConnection, HTTPAuthorizationCredentials | None, OptStr],
             AnyAuthorization,
-        ],
-        Callable[
-            [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
-            OptionalAnyAuthorization,
-        ],
-        Callable[
-            [Request, Optional[HTTPAuthorizationCredentials], OptionalString],
+        ]
+        | Callable[
+            [Request, HTTPAuthorizationCredentials | None, OptStr],
+            OptAnyAuthorization,
+        ]
+        | Callable[
+            [Request, HTTPAuthorizationCredentials | None, OptStr],
             AnyAuthorization,
-        ],
-        Callable[[WebSocket], OptionalAnyAuthorization],
-        Callable[[WebSocket], AnyAuthorization],
-    ]:
+        ]
+        | Callable[[WebSocket], OptAnyAuthorization]
+        | Callable[[WebSocket], AnyAuthorization]
+    ):
         if scheme is None:
             return BaseAuthorization.as_dependency(protocol, auto_error=auto_error)
         elif scheme is Scheme.API_KEY:
@@ -779,7 +777,7 @@ class Factory:
         cls,
         scheme: Literal[Scheme.API_KEY],
         *,
-        authorization: Union[str, APIKeyAuthorization],
+        authorization: str | APIKeyAuthorization,
     ) -> APIKeyAuth: ...
     @overload
     @classmethod
@@ -787,14 +785,14 @@ class Factory:
         cls,
         scheme: Literal[Scheme.BEARER_TOKEN] = Scheme.BEARER_TOKEN,
         *,
-        authorization: Union[str, BearerTokenAuthorization],
+        authorization: str | BearerTokenAuthorization,
     ) -> BearerTokenAuth: ...
     @classmethod
     def httpx_auth(
         cls,
         scheme: Scheme = Scheme.BEARER_TOKEN,
         *,
-        authorization: Union[str, AnyAuthorization],
+        authorization: str | AnyAuthorization,
     ) -> AnyHTTPXAuthorization:
         if isinstance(authorization, str):
             token = authorization
